Type: Package
Package: neuroSCC
Title: Bridging Simultaneous Confidence Corridors and PET Neuroimaging
Version: 1.0.2
Authors@R: c(
    person("Juan A.", "Arias Lopez", , "iguanamarina@protonmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-3355-6393")),
    person("Virgilio", "Gomez Rubio", , "Virgilio.Gomez@uclm.es", role = "rev",
           comment = c(ORCID = "0000-0002-4791-3072")),
    person("Pablo", "Aguiar Fernandez", , "pablo.aguiar@usc.es", role = "ths",
           comment = c(ORCID = "0000-0002-7322-2195")),
    person("Andrew", "Haddon Kemp", , "A.H.Kemp@swansea.ac.uk", role = "ths",
           comment = c(ORCID = "0000-0003-1146-3791"))
  )
Maintainer: Juan A. Arias Lopez <iguanamarina@protonmail.com>
Description: Tools for the structured processing of PET neuroimaging data 
    in preparation for the estimation of Simultaneous Confidence Corridors (SCCs) 
    for one-group, two-group, or single-patient vs group comparisons. 
    The package facilitates PET image loading, data restructuring, integration 
    into a Functional Data Analysis framework, contour extraction, identification 
    of significant results, and performance evaluation. It bridges established 
    packages (e.g., 'oro.nifti') with novel statistical methodologies (e.g., 
    'ImageSCC') and enables reproducible analysis pipelines, including 
    comparison with Statistical Parametric Mapping ('SPM').
License: MIT + file LICENSE
URL: https://iguanamarina.github.io/neuroSCC/,
        https://github.com/iguanamarina/PhD-2023-SCC-vs-SPM-Group-vs-Group,
        https://github.com/iguanamarina/PhD-2024-SCC-vs-SPM-SinglePatient-vs-Group
BugReports: https://github.com/iguanamarina/neuroSCC/issues
Depends: R (>= 4.2.0)
Imports: dplyr, graphics, memisc, oro.nifti, stats, tidyr, utils
Suggests: BPST, fields, ggplot2, ImageSCC, knitr, patchwork, rcmdcheck,
        remotes, rmarkdown, roxygen2 (>= 7.1.0), scales, Triangulation,
        viridis
Additional_repositories: https://iguanamarina.github.io/neuroSCC-drat
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-04-18 08:45:46 UTC; juana
Author: Juan A. Arias Lopez [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3355-6393>),
  Virgilio Gomez Rubio [rev] (ORCID:
    <https://orcid.org/0000-0002-4791-3072>),
  Pablo Aguiar Fernandez [ths] (ORCID:
    <https://orcid.org/0000-0002-7322-2195>),
  Andrew Haddon Kemp [ths] (ORCID:
    <https://orcid.org/0000-0003-1146-3791>)
Repository: CRAN
Date/Publication: 2026-04-18 09:00:02 UTC
Built: R 4.5.2; ; 2026-04-20 23:38:42 UTC; unix

Type: Package
Package: neuroSCC
Title: Bridging Simultaneous Confidence Corridors and PET Neuroimaging
Version: 1.0.2
Authors@R: c(
    person("Juan A.", "Arias Lopez", , "iguanamarina@protonmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-3355-6393")),
    person("Virgilio", "Gomez Rubio", , "Virgilio.Gomez@uclm.es", role = "rev",
           comment = c(ORCID = "0000-0002-4791-3072")),
    person("Pablo", "Aguiar Fernandez", , "pablo.aguiar@usc.es", role = "ths",
           comment = c(ORCID = "0000-0002-7322-2195")),
    person("Andrew", "Haddon Kemp", , "A.H.Kemp@swansea.ac.uk", role = "ths",
           comment = c(ORCID = "0000-0003-1146-3791"))
  )
Maintainer: Juan A. Arias Lopez <iguanamarina@protonmail.com>
Description: Tools for the structured processing of PET neuroimaging data 
    in preparation for the estimation of Simultaneous Confidence Corridors (SCCs) 
    for one-group, two-group, or single-patient vs group comparisons. 
    The package facilitates PET image loading, data restructuring, integration 
    into a Functional Data Analysis framework, contour extraction, identification 
    of significant results, and performance evaluation. It bridges established 
    packages (e.g., 'oro.nifti') with novel statistical methodologies (e.g., 
    'ImageSCC') and enables reproducible analysis pipelines, including 
    comparison with Statistical Parametric Mapping ('SPM').
License: MIT + file LICENSE
URL: https://iguanamarina.github.io/neuroSCC/,
        https://github.com/iguanamarina/PhD-2023-SCC-vs-SPM-Group-vs-Group,
        https://github.com/iguanamarina/PhD-2024-SCC-vs-SPM-SinglePatient-vs-Group
BugReports: https://github.com/iguanamarina/neuroSCC/issues
Depends: R (>= 4.2.0)
Imports: dplyr, graphics, memisc, oro.nifti, stats, tidyr, utils
Suggests: BPST, fields, ggplot2, ImageSCC, knitr, patchwork, rcmdcheck,
        remotes, rmarkdown, roxygen2 (>= 7.1.0), scales, Triangulation,
        viridis
Additional_repositories: https://iguanamarina.github.io/neuroSCC-drat
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-04-18 08:45:46 UTC; juana
Author: Juan A. Arias Lopez [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3355-6393>),
  Virgilio Gomez Rubio [rev] (ORCID:
    <https://orcid.org/0000-0002-4791-3072>),
  Pablo Aguiar Fernandez [ths] (ORCID:
    <https://orcid.org/0000-0002-7322-2195>),
  Andrew Haddon Kemp [ths] (ORCID:
    <https://orcid.org/0000-0003-1146-3791>)
Repository: CRAN
Date/Publication: 2026-04-18 09:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 22:51:00 UTC; unix

# Generated by roxygen2: do not edit by hand

export(calculateMetrics)
export(databaseCreator)
export(generatePoissonClones)
export(getDimensions)
export(getPoints)
export(getSPMbinary)
export(matrixCreator)
export(meanNormalization)
export(neuroCleaner)
export(neuroContour)
export(plotSCCcomparisonPanel)
export(plotSCCpanel)
export(plotValidationPanel)
export(processROIs)
importFrom(graphics,points)
importFrom(stats,rpois)
importFrom(utils,globalVariables)

# neuroSCC <img src="man/figures/logo.png" align="right" width="150"/>

[![Project
Status](http://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/)
[![Lifecycle](https://img.shields.io/badge/lifecycle-Stable-4cc71e.svg)](https://lifecycle.r-lib.org/articles/stages.html)
[![Contributors](https://img.shields.io/badge/Contributors-1-brightgreen)](https://github.com/iguanamarina/neuroSCC/graphs/contributors)
[![Commits](https://img.shields.io/badge/Commits-NA-brightgreen)](https://github.com/iguanamarina/neuroSCC/commits/main)
[![Issues](https://img.shields.io/badge/Issues-22-brightgreen)](https://github.com/iguanamarina/neuroSCC/issues)
[![Size](https://img.shields.io/badge/Size-106908KB-brightgreen)](https://github.com/iguanamarina/neuroSCC)

🚀 **`neuroSCC` Bridging Simultaneous Confidence Corridors and PET
Neuroimaging.** This package facilitates structured processing of PET
neuroimaging data for the estimation of Simultaneous Confidence
Corridors (SCCs). It integrates neuroimaging and statistical
methodologies to:

- 📥 **Load and preprocess** PET neuroimaging files.  
- 🔬 **Transform data** for a **Functional Data Analysis (FDA)**
  setup.  
- 🎯 **Extract meaningful contours** and identify significant SCC
  regions.  
- 📊 **Compare SCC-based analyses** with gold-standard methods like
  **SPM**.

The package bridges established **[neuroimaging
tools](https://github.com/bjw34032/oro.nifti)** (`oro.nifti`) with
advanced **[statistical
methods](https://github.com/FIRST-Data-Lab/ImageSCC)** (`ImageSCC`),
supporting **one-group, two-group, and single-patient vs. group
comparisons**.

📌 Developed as part of the **Ph.D. thesis**: *“Development of
statistical methods for neuroimage data analysis towards early diagnosis
of neurodegenerative diseases”*, by Juan A. Arias at **University of
Santiago de Compostela (Spain)**.

💡 This work was partially supported by an **internship grant awarded at
the 6th Conference of the Spanish National Biostatistics Network
(BIOSTATNET)** in 2025, as a prize for best poster presentation and
young researcher trajectory.

------------------------------------------------------------------------

# 📖 Table of Contents

- [About the Project](#about-the-project)
- [Installation](#installation)
- [Functions Overview](#functions-overview)
- [Vignette](#vignette)
- [Visual Workflow](#visual-workflow)
- [References](#references)
- [Contributing & Feedback](#contributing-feedback)

------------------------------------------------------------------------

# 1️⃣ About the Project <a name="about-the-project"></a>

## Why Use `neuroSCC`?

PET neuroimaging data is **complex**, requiring careful **processing and
statistical validation**. `neuroSCC` is designed to:

✔ **Automate Preprocessing**: Load, clean, and structure PET data 📂  
✔ **Standardize Analysis**: Convert images into FDA-compatible formats
🔬  
✔ **Evaluate SCC Estimations**: Identify **significant regions** with
confidence 🎯  
✔ **Enable Method Comparisons**: SCC vs SPM **performance evaluation**
📊

It is **particularly suited for**: - **Clinical neuroimaging research**
(Alzheimer’s disease, neurodegeneration). - **Statistical validation of
imaging methods**. - **Comparisons between SCC and other statistical
approaches**.

------------------------------------------------------------------------

# 2️⃣ Installation <a id="installation"></a>

## 🔹 Stable GitHub Release (Future)

``` r
# Install the latest stable release (Future)
remotes::install_github("iguanamarina/neuroSCC@1a91f8e")
library(neuroSCC)
```

## 📦 Development Version (Latest Features)

``` r
# Install the latest development version
remotes::install_github("iguanamarina/neuroSCC")
library(neuroSCC)
```

## 🔜 From CRAN (Future)

``` r
# Once available on CRAN
install.packages("neuroSCC")
library(neuroSCC)
```

------------------------------------------------------------------------

# 3️⃣ Functions Overview<a id="functions-overview"></a>

## 🧼 neuroCleaner(): Load & Clean PET Data

`neuroCleaner()` reads **NIFTI neuroimaging files**, extracts
**voxel-wise data**, and structures it into a **tidy data frame**.  
It is the **first preprocessing step**, ensuring that PET images are
cleaned and formatted for further analysis. It also integrates
demographic data when available.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Load a sample Control NIfTI file
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
# Example Without demographic data
petData <- neuroCleaner(niftiFile)
petData[sample(nrow(petData), 10), ]  # Show 10 random voxels
```

</details>

## 📊 databaseCreator(): Convert Multiple Files into a Database

`databaseCreator()` scans a directory for **PET image files**, processes
each with `neuroCleaner()`, and compiles them into a **structured data
frame**.  
This function is **critical for batch analysis**, preparing data for
group-level SCC comparisons.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
#' @examples
#' # NOTE: To keep runtime below CRAN limits, this example processes only 1 subject.
#' # You can expand the pattern to include all subjects for real use.
#'
#' # Example: Create a database from a single synthetic PET image (control group)
#' controlPattern <- "^syntheticControl1\\.nii\\.gz$"
#' databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
#'
#' head(databaseControls)
```

</details>

## 📐 getDimensions(): Extract Image Dimensions

`getDimensions()` extracts the **spatial dimensions** of a neuroimaging
file, returning the number of **voxels in the x, y, and z axes**.  
This ensures proper alignment of neuroimaging data before further
processing.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Extract spatial dimensions of a PET scan
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
dims <- getDimensions(niftiFile)
print(dims)
```

</details>

## 📊 matrixCreator(): Convert PET Data into a Functional Matrix

`matrixCreator()` transforms **PET imaging data into a matrix format**
for functional data analysis.  
Each row represents a subject’s PET data, formatted to align with FDA
methodologies.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# NOTE: To keep example runtime short, only one synthetic PET file is used.
# For full analysis, expand the filename pattern accordingly.
# Step 1: Generate a database for a single subject
controlPattern <- "^syntheticControl1\\.nii\\.gz$"
databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
# Step 2: Convert the database into a matrix format
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
# Display dimensions of the matrix
dim(matrixControls)
```

</details>

## 📉 meanNormalization(): Normalize Data

`meanNormalization()` performs **row-wise mean normalization**,
adjusting intensity values across subjects.  
This removes global intensity differences, making datasets comparable in
**Functional Data Analysis (FDA)**.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Generate a minimal database and create a matrix (1 control subject)
dataDir <- system.file("extdata", package = "neuroSCC")
controlPattern <- "^syntheticControl1\\.nii\\.gz$"
databaseControls <- databaseCreator(pattern = controlPattern,
                                    control = TRUE,
                                    quiet = TRUE)
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
# Normalize the matrix (with diagnostics)
normalizationResult <- meanNormalization(matrixControls,
                                         returnDetails = TRUE,
                                         quiet = FALSE)
```

</details>

## 📈 neuroContour(): Extract Contours

`neuroContour()` extracts **region boundaries (contours) from
neuroimaging data**.  
It identifies the boundary of the **non-zero support** in a given slice,
making it useful for defining **masks or Regions of Interest (ROIs)**
before SCC computation.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Get the file path for a sample NIfTI file
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Extract contours from the non-zero support
contours <- neuroContour(niftiFile, paramZ = 35, plotResult = TRUE)

# Display the extracted contour coordinates
if (length(contours) > 0) {
  head(contours[[1]])  # Show first few points of the main contour
}
```

</details>

## 🔺 getPoints(): Identify Significant SCC Differences

`getPoints()` identifies **regions with significant differences** from
an SCC computation.  
After `ImageSCC::scc.image()` computes SCCs, `getPoints()` extracts
**coordinates where group differences exceed confidence boundaries**.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Load precomputed SCC example
data("SCCcomp", package = "neuroSCC")

# Extract significant SCC points
significantPoints <- getPoints(SCCcomp)

# Show first extracted points (interpretation depends on SCC computation, see description)
head(significantPoints$positivePoints)  # Regions where Pathological is hypoactive vs. Control
head(significantPoints$negativePoints)  # Regions where Pathological is hyperactive vs. Control
```

</details>

## 🧩 getSPMbinary(): Extract SPM-Detected Significant Points

`getSPMbinary()` extracts **significant points** from an **SPM-generated
binary NIfTI file**.  
It returns voxel coordinates where **SPM detected significant
differences**, making it comparable to SCC results.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Load a sample binary NIfTI file (SPM result)
niftiFile <- system.file("extdata", "binary.nii", package = "neuroSCC")
detectedSPM <- getSPMbinary(niftiFile, paramZ = 35)

# Show detected points
head(detectedSPM)
```

</details>

## 🏷️ processROIs(): Process ROI Data

`processROIs()` processes **Regions of Interest (ROIs)** from
neuroimaging files.  
It extracts voxel coordinates for **predefined hypoactive regions**,
structuring them for SCC analysis.

*Example with Code:*
<details>

<summary>

Click to expand
</summary>

``` r
# Load and process a sample ROI NIfTI file (console output)
roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
processedROI <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
head(processedROI)
```

</details>

## 👥 generatePoissonClones(): Generate Synthetic PET Data

`generatePoissonClones()` creates **synthetic clones of PET neuroimaging
data** by adding Poisson-distributed noise. This function is essential
for **1 vs. Group SCC analyses**, where a single subject’s data needs to
be expanded to allow for valid statistical inference.

*Example with Code:*  
<details>

<summary>

Click to expand
</summary>

``` r
# Load example input matrix for Poisson cloning
data("generatePoissonClonesExample", package = "neuroSCC")
# Select 10 random voxel positions for display
set.seed(123)
sampledCols <- sample(ncol(generatePoissonClonesExample), 10)
# Generate 1 synthetic clone
clones <- generatePoissonClones(generatePoissonClonesExample, numClones = 1, lambdaFactor = 0.25)
# Show voxel intensity values after cloning
clones[, sampledCols]
```

</details>

## 📊 calculateMetrics(): Evaluate SCC Performance

`calculateMetrics()` assesses the accuracy of **SCC-detected significant
points** by comparing them to known **true ROI regions**. It computes
**Sensitivity, Specificity, PPV, and NPV**, allowing for a quantitative
evaluation of SCC performance.

*Example with Code:*  
<details>

<summary>

Click to expand
</summary>

``` r
data("calculateMetricsExample", package = "neuroSCC")
# Evaluate SCC and SPM detection performance
with(calculateMetricsExample, {
  metricsSCC <- calculateMetrics(detectedSCC, trueROI, totalCoords, "Region2_SCC")
  metricsSPM <- calculateMetrics(detectedSPM, trueROI, totalCoords, "Region2_SPM")
  print(metricsSCC)
  print(metricsSPM)
})
```

</details>

## 🎨 plotSCCpanel(): Visualize One-Group SCC Bands

`plotSCCpanel()` displays the **lower SCC band, mean estimate, and upper
SCC band** for a **single-group SCC analysis** in a clean three-panel
layout. It is especially useful for creating **publication-ready
figures** of one-group SCC results.

*Example with Code:*  
<details>

<summary>

Click to expand
</summary>

``` r
data("sccOneGroup", package = "neuroSCC")

plotSCCpanel(
  scc = sccOneGroup,
  title = "SCC FOR CONTROL GROUP"
)
```

</details>

## 🔬 plotSCCcomparisonPanel(): Compare Two SCC Groups

`plotSCCcomparisonPanel()` visualizes **two group mean estimates side by
side** together with an **SCC overlay panel highlighting detected
differences**. This is ideal for **group-vs-group SCC interpretation and
figure generation**.

*Example with Code:*  
<details>

<summary>

Click to expand
</summary>

``` r
data("SCCcomp", package = "neuroSCC")

plotSCCcomparisonPanel(
  scc = SCCcomp,
  title = "SCC COMPARISON PANEL"
)
```

</details>

## 🧪 plotValidationPanel(): Validate SCC Against SPM

`plotValidationPanel()` creates a **three-panel validation figure**
comparing the **ground-truth ROI**, **SCC detections**, and **SPM
detections** over the same neuroimaging background. It is designed for
**method comparison, validation studies, and article figures**.

*Example with Code:*

<details>

<summary>

Click to expand
</summary>

``` r
paramZ <- 35

controlPattern <- "^syntheticControl.*\\.nii\\.gz$"
databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
matrixCN <- meanNormalization(matrixCN)

roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))

spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)

data("SCCcomp", package = "neuroSCC")

plotValidationPanel(
  template = roiFile,
  backgroundMatrix = matrixCN,
  roiPoints = roiPoints,
  sccPoints = list(
    positivePoints = getPoints(SCCcomp)$positivePoints,
    negativePoints = data.frame(x = numeric(0), y = numeric(0))
  ),
  spmPoints = spmPoints,
  title = "Performance Validation Panel",
  label1 = "Ground Truth (ROI)",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)
```

</details>

------------------------------------------------------------------------

# 4️⃣ Vignette <a id="vignette"></a>

A full walkthrough of using `neuroSCC` from start to finish is available
in the vignettes:

- 📌 **[Landing
  Vignette](https://iguanamarina.github.io/neuroSCC/articles/landing_vignette.html)**  
  *Covers data loading, matrix creation, and triangulations.*

- 📌 **[Two-group SCC Estimation &
  Comparison](https://iguanamarina.github.io/neuroSCC/articles/two_group_comparison.html)**  
  *Computes SCCs for the differences between two groups and identifies
  voxels outside of estimated confidence intervals.*

- 📌 **[1vsGroup SCC Estimation &
  Comparison](https://iguanamarina.github.io/neuroSCC/articles/one_vs_group.html)**  
  *Compares an individual patient to a control group using SCCs and
  identifies voxels outside of estimated confidence intervals.*

# 5️⃣ Visual Workflow <a id="visual-workflow"></a>

A complete visual overview of how `neuroSCC` functions interact with
data, the objects they return, and more, can be found in the Visual
Workflow:

<p align="center">

<img src="man/figures/workflow.png" alt="NeuroSCC Workflow" width="100%">
</p>

------------------------------------------------------------------------

# 6️⃣ References <a id="references"></a>

- Wang, Y., Wang, G., Wang, L., & Ogden, R.T. (2020). *Simultaneous
  Confidence Corridors for Mean Functions in Functional Data Analysis of
  Imaging Data*. Biometrics, 76(2), 427-437. <doi:10.1111/biom.13156>

- Arias-López, J. A., Cadarso-Suárez, C., & Aguiar-Fernández, P. (2021).
  *Computational Issues in the Application of Functional Data Analysis
  to Imaging Data*. In *International Conference on Computational
  Science and Its Applications* (pp. 630–638). Springer International
  Publishing, Cham. <doi:10.1007/978-3-030-86960-1_46>

- Arias-López, J. A., Cadarso-Suárez, C., & Aguiar-Fernández, P. (2022).
  *Functional Data Analysis for Imaging Mean Function Estimation:
  Computing Times and Parameter Selection*. *Computers*, 11(6), 91.
  MDPI. <doi:10.3390/computers11060091>

<<<<<<< Updated upstream
- **Ph.D. Thesis:** Arias-López, J. A. (2025). *Development of Statistical Methods for Neuroimage Data Analysis Towards Early Diagnosis of Neurodegenerative Diseases*. University of Santiago de Compostela. Outstanding *Summa Cum Laude*.
=======
- **Ph.D. Thesis:** Arias-López, J. A. (2025). *Development of
  Statistical Methods for Neuroimage Data Analysis Towards Early
  Diagnosis of Neurodegenerative Diseases*. University of Santiago de
  Compostela. **Summa Cum Laude**.
>>>>>>> Stashed changes

------------------------------------------------------------------------

# 📢 Contributing & Feedback <a id="contributing-feedback"></a>

We welcome **contributions, feedback, and issue reports** from the
community! If you would like to help improve `neuroSCC`, here’s how you
can get involved:

## 🐛 Found a Bug? Report an Issue

If you encounter a bug, incorrect result, or any unexpected behavior,
please:

1.  Check **[existing
    issues](https://github.com/iguanamarina/neuroSCC/issues)** to see if
    it has already been reported.  
2.  If not, [open a new
    issue](https://github.com/iguanamarina/neuroSCC/issues/new) and
    include:
    - A **clear description** of the problem.  
    - Steps to **reproduce** the issue.  
    - Any **error messages** or screenshots (if applicable).

## 💡 Have an Idea? Suggest a Feature

We are always looking to improve `neuroSCC`. If you have a **suggestion
for a new feature** or an enhancement, please:

1.  Browse the **[open
    discussions](https://github.com/iguanamarina/neuroSCC/discussions)**
    to see if your idea has already been suggested.  
2.  If not, start a **new discussion thread** with:
    - A **detailed explanation** of your idea.  
    - Why it would **improve** the package.  
    - Any **relevant references** or examples from similar projects.

## 🔧 Want to Contribute Code?

We love contributions! To submit **a pull request (PR)**:

1.  **Fork the repository** on GitHub.  

2.  **Clone your fork** to your local machine:

    ``` r
    git clone https://github.com/YOUR_USERNAME/neuroSCC.git
    cd neuroSCC
    ```

3.  **Create a new branch** for your feature or fix:

    ``` r
    git checkout -b feature-new-functionality
    ```

4.  **Make your changes** and commit them:

    ``` r
    git add .
    git commit -m "Added new functionality XYZ"
    ```

5.  **Push your changes** to your fork:

    ``` r
    git push origin feature-new-functionality
    ```

6.  **Submit a pull request** (PR) from your forked repository to the
    main `neuroSCC` repository.

Before submitting, please:  
✔ Ensure your code **follows the package style guidelines**.  
✔ Add **documentation** for any new functions or features.  
✔ Run **`devtools::check()`** to verify that all package tests pass.

## 📧 Contact & Support

For questions not related to bugs or feature requests, feel free to:  
📬 Email the maintainer: <iguanamarina@protonmail.com>  
💬 Join the discussion on **[GitHub
Discussions](https://github.com/iguanamarina/neuroSCC/discussions)**

------------------------------------------------------------------------

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(neuroSCC)

## -----------------------------------------------------------------------------
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Load and clean data using neuroCleaner
petData <- neuroCleaner(niftiFile)

# Inspect the data
head(petData)
str(petData)

## -----------------------------------------------------------------------------
# Create database for control subjects
controlPattern <- "^syntheticControl.*\\.nii.gz$"
databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = FALSE)

# Inspect the created database
head(databaseControls)
table(databaseControls$CN_number)

## -----------------------------------------------------------------------------
# Create matrix for Z-slice 35
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = FALSE)

# Inspect matrix structure
dim(matrixControls)
str(matrixControls)

## -----------------------------------------------------------------------------
# Perform mean normalization
normalizedMatrix <- meanNormalization(matrixControls, returnDetails = FALSE)


## ----fig.alt="Contours for brain imaging data"--------------------------------
# Extract contours from sample data
contours <- neuroContour(niftiFile, paramZ = 35, plotResult = TRUE)

# Check contours structure
length(contours)
str(contours[[1]])

## ----fig.alt="Delaunay triangulations for brain imaging data", eval = requireNamespace("ImageSCC", quietly = TRUE)----

if (!requireNamespace("Triangulation", quietly = TRUE)) {
  cat("Triangulation package is not installed.\nInstall it using: remotes::install_github('FIRST-Data-Lab/Triangulation')\n")
} else {
  # Perform triangulation with the first contour
  mesh <- Triangulation::TriMesh(n = 15, contours[[1]])
  
  # Inspect mesh
  print(mesh[["V"]][1:10, ])
  print(mesh[["Tr"]][1:10, ])
}

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----eval=TRUE, echo=FALSE----------------------------------------------------
library(neuroSCC)

## -----------------------------------------------------------------------------
cat("Creating required matrices from sample data...\n")

databaseControls <- databaseCreator(pattern = "^syntheticControl.*\\.nii\\.gz$", control = TRUE, quiet = TRUE)
databasePathological <- databaseCreator(pattern = "^syntheticPathological1\\.nii\\.gz$", control = FALSE, quiet = TRUE)

matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
matrixPathological <- matrixCreator(databasePathological, paramZ = 35, quiet = TRUE)

normalizedMatrix <- meanNormalization(matrixControls)
normalizedPathological <- meanNormalization(matrixPathological)

niftiPath <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
contours <- neuroContour(niftiPath, paramZ = 35, plotResult = FALSE)

cat("Data prepared successfully.\n")

## -----------------------------------------------------------------------------
# Select the single pathological patient
SCC_AD <- normalizedPathological[1, , drop = FALSE]
SCC_CN <- normalizedMatrix

# Toy parameters for Poisson clone generation (modifiable by user)
numClones <- 2
factorLambda <- 0.1

# Generate synthetic clones
SCC_AD_clones <- generatePoissonClones(SCC_AD, numClones, factorLambda)

# Combine the patient with generated clones
SCC_AD_expanded <- rbind(SCC_AD, SCC_AD_clones)
SCC_AD_expanded <- meanNormalization(SCC_AD_expanded)

## -----------------------------------------------------------------------------
if (requireNamespace("ImageSCC", quietly = TRUE)) {
  message("'ImageSCC' package is available.")
} else {
  message("This vignette requires the 'ImageSCC' package.")
  message("You can install it from GitHub with:")
  message("  remotes::install_github('FIRST-Data-Lab/ImageSCC')")
}

## ----eval = requireNamespace("ImageSCC", quietly = TRUE), echo=TRUE-----------

# Check for Triangulation package
triangulation_available <- requireNamespace("Triangulation", quietly = TRUE)

if (triangulation_available) {
  message("'Triangulation' package is available.")
} else {
  message("'Triangulation' package not available.")
  message("Install with: remotes::install_github('FIRST-Data-Lab/Triangulation')")
}

# Proceed only if both packages are available
if (triangulation_available) {

  # Try loading precomputed SCC object from data/
  if (!exists("SCCcomp", inherits = FALSE) &&
      "SCCcomp" %in% data(package = "neuroSCC")$results[, "Item"]) {
    
    message("Loading precomputed SCC object from package data...")
    suppressMessages(data("SCCcomp", package = "neuroSCC"))

  } else if (!exists("SCCcomp", inherits = FALSE)) {
    
    message("Precomputed object not found. Running SCC estimation...")

    # 1. Prepare contour and triangulation
    Z <- as.matrix(contours[[1]][, c("x", "y")])
    VT <- Triangulation::TriMesh(contours[[1]], n = 15)
    V <- as.matrix(VT[[1]])
    Tr <- as.matrix(VT[[2]])

    # 2. Run SCC estimation
    SCCcomp <- ImageSCC::scc.image(
      Ya = SCC_AD_expanded,
      Yb = SCC_CN,
      Z = Z,
      d.est = 5,
      d.band = 2,
      r = 1,
      V.est.a = V,
      Tr.est.a = Tr,
      V.band.a = V,
      Tr.band.a = Tr,
      penalty = TRUE,
      lambda = 10^{seq(-6, 3, 0.5)},
      alpha.grid = c(0.10, 0.05, 0.01),
      adjust.sigma = TRUE
    )
  }
}



## ----eval=TRUE----------------------------------------------------------------
if (!exists("SCCcomp", inherits = FALSE)) {
  data("SCCcomp", package = "neuroSCC")
}

## ----eval=TRUE, fig.alt="Single-group SCC panel for the control group"--------
data("sccOneGroup", package = "neuroSCC")

plotSCCpanel(
  scc = sccOneGroup,
  title = "SCC FOR CONTROL GROUP"
)

## ----eval=TRUE, fig.alt="Two-group SCC comparison panel"----------------------
plotSCCcomparisonPanel(
  scc = SCCcomp,
  title = "SCC COMPARISON PANEL"
)

## ----eval=TRUE----------------------------------------------------------------
# Extract significant points
significantPoints <- getPoints(SCCcomp)

# Load example true ROI data from the package
roi_path <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
trueROI <- processROIs(roi_path, region = "Region2", number = "18", save = FALSE)

# Get dimensions for total coordinates
dimensions <- getDimensions(roi_path)
totalCoords <- expand.grid(x = 1:dimensions$xDim, y = 1:dimensions$yDim)

# Calculate performance metrics
metrics <- calculateMetrics(
  detectedPoints = significantPoints$positivePoints,
  truePoints = trueROI,
  totalCoords = dimensions,
  regionName = "SinglePatient_vs_Group"
)

# Display metrics
print(metrics)

## ----eval=TRUE, fig.alt="Validation panel comparing ROI, SCC, and SPM detections"----
paramZ <- 35

controlPattern <- "^syntheticControl.*\\.nii\\.gz$"
databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
matrixCN <- meanNormalization(matrixCN)

roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))

spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)

plotValidationPanel(
  template = roiFile,
  backgroundMatrix = matrixCN,
  roiPoints = roiPoints,
  sccPoints = list(
    positivePoints = getPoints(SCCcomp)$positivePoints,
    negativePoints = data.frame(x = numeric(0), y = numeric(0))
  ),
  spmPoints = spmPoints,
  title = "Performance Validation Panel",
  label1 = "Ground Truth (ROI)",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)

# Internal helpers for contour extraction from non-zero image support

# Internal helper: polygon area
#' @keywords internal
.poly_area_xy <- function(x, y) {
  if (!(x[1] == x[length(x)] && y[1] == y[length(y)])) {
    x <- c(x, x[1])
    y <- c(y, y[1])
  }

  abs(sum(x[-1] * y[-length(y)] - x[-length(x)] * y[-1])) / 2
}

# Internal helper: extract contours from non-zero image support
#' @keywords internal
.extract_mask_contours <- function(dat, contour_level = 0.1) {
  if (!is.data.frame(dat) || !all(c("x", "y", "value") %in% names(dat))) {
    stop("'dat' must be a data.frame with columns 'x', 'y', and 'value'")
  }

  xMax <- max(dat$x)
  yMax <- max(dat$y)

  mask_num <- matrix(0, nrow = xMax, ncol = yMax)
  mask_num[cbind(dat$x, dat$y)] <- as.numeric(dat$value != 0)

  cl <- grDevices::contourLines(
    x = 1:xMax,
    y = 1:yMax,
    z = mask_num,
    levels = contour_level
  )

  if (length(cl) == 0) {
    return(list())
  }

  areas <- vapply(
    cl,
    function(one) .poly_area_xy(one$x, one$y),
    numeric(1)
  )

  ord <- order(areas, decreasing = TRUE)

  lapply(cl[ord], function(one) {
    data.frame(
      x = one$x,
      y = one$y
    )
  })
}

#' Precomputed Inputs for SCC vs. SPM Performance Evaluation
#'
#' @name calculateMetricsExample
#' @docType data
#'
#' @description
#' A dataset containing all necessary inputs for demonstrating \code{\link{calculateMetrics}}.
#' It enables reproducible and fast example code that compares SCC-detected and SPM-detected
#' points against a known ground truth ROI.
#'
#' These inputs were generated using sample PET and ROI files included in the \code{neuroSCC} package.
#'
#' @format A set of four objects:
#' \describe{
#'   \item{\code{detectedSCC}}{Data frame of SCC-detected coordinates (from \code{\link{getPoints}}).}
#'   \item{\code{detectedSPM}}{Data frame of SPM-detected coordinates (from \code{\link{getSPMbinary}}).}
#'   \item{\code{trueROI}}{Ground truth ROI voxel data (from \code{\link{processROIs}}).}
#'   \item{\code{totalCoords}}{List with full image grid dimensions (from \code{\link{getDimensions}}).}
#' }
#'
#' @usage data("calculateMetricsExample")
#'
#' @seealso \code{\link{calculateMetrics}}, \code{\link{getPoints}}, \code{\link{getSPMbinary}},
#'          \code{\link{processROIs}}, \code{\link{getDimensions}}
#'
#' @source Simulated PET neuroimaging study for testing SCC and SPM detection accuracy.
#'
#' @keywords datasets
NULL

#' Example SCC Computation Result
#'
#' @description
#' A precomputed example of a Simultaneous Confidence Corridor (SCC) analysis
#' comparing a group of pathological subjects against controls. This object was generated
#' using the \code{ImageSCC::scc.image} function and represents a realistic output
#' from SCC-based neuroimaging group comparisons.
#'
#' This dataset is used in the examples of \code{\link{getPoints}} and \code{\link{calculateMetrics}},
#' allowing users to explore SCC outputs without needing to recompute them.
#'
#' @format A named list of class \code{"image"} with the following elements
#' \describe{
#'   \item{\code{scc}}{3D array of SCC confidence bands, dimensions \code{[n, 2, alpha]}.}
#'   \item{\code{Z.band}}{Matrix of grid coordinates corresponding to evaluated locations.}
#'   \item{\code{ind.inside.cover}}{Integer vector of indices for grid points inside the SCC band.}
#'   \item{\code{V.est.a}, \code{V.est.b}}{Vertex matrices for triangulated domains (pathological and control groups).}
#'   \item{\code{Tr.est.a}, \code{Tr.est.b}}{Triangle index matrices corresponding to the domain meshes.}
#'   \item{\code{alpha}}{Vector of confidence levels used (e.g., 0.1, 0.05, 0.01).}
#'   \item{\code{d.est}}{Spline degree used in mean function estimation.}
#'   \item{\code{r}}{Smoothing parameter used during fitting.}
#' }
#'
#' @usage data("SCCcomp")
#'
#' @seealso \code{\link{getPoints}}, \code{\link{calculateMetrics}}, \code{ImageSCC::scc.image}
#'
#' @source Simulated PET neuroimaging study for evaluating SCC methodology.
#'
#' @keywords datasets
"SCCcomp"

#' Plot SCC bands and mean estimate for a single group
#'
#' @description
#' This function visualizes the lower band, mean estimate, and upper band
#' from a single-group Simultaneous Confidence Corridor (SCC) result.
#' It returns a three-panel plot showing the estimated mean function and
#' its confidence bands over the neuroimaging domain.
#'
#' @param scc A list-like SCC result object, typically returned by
#'   \code{ImageSCC::scc.image()}, containing at least the components
#'   \code{Z}, \code{ind.inside.cover}, \code{scc}, and \code{Yhat}.
#' @param title \code{character}, title shown above the panel. If \code{NULL},
#'   the default title is \code{"SCC FOR GROUP 1"}.
#' @param zlim Either \code{"auto"} to compute color limits from the plotted values,
#'   or a numeric vector of length 2 specifying the lower and upper limits of the
#'   fill scale.
#' @param palette \code{character}, color palette used in the heatmaps.
#'   Supported values are \code{"nih"}, \code{"viridis"}, and \code{"gray"}.
#'
#' @return A patchwork/ggplot object containing three aligned panels:
#' \itemize{
#'   \item lower SCC band,
#'   \item mean estimate,
#'   \item upper SCC band.
#' }
#'
#' @details
#' The three panels are displayed using a shared color scale so that the lower band,
#' mean estimate, and upper band can be compared directly.
#'
#' The function assumes that the second slice of \code{scc$scc[, , 2]} corresponds
#' to the SCC bands for the default significance level used in the package workflow.
#'
#' @examples
#' data("sccOneGroup", package = "neuroSCC")
#' plotSCCpanel(sccOneGroup, title = "SCC FOR CONTROL GROUP")
#'
#' @seealso
#' \code{\link{sccOneGroup}} for the example single-group SCC object used in the examples. \cr
#' \code{\link{SCCcomp}} for a two-group SCC example object. \cr
#' \code{\link{plotSCCcomparisonPanel}} for two-group SCC visualization. \cr
#' \code{\link{plotValidationPanel}} for SCC versus SPM performance visualization.
#'
#' @export
plotSCCpanel <- function(scc, title = NULL, zlim = "auto", palette = "nih") {
  if (!requireNamespace("ggplot2", quietly = TRUE)) {
    stop("Package 'ggplot2' is required.")
  }
  if (!requireNamespace("patchwork", quietly = TRUE)) {
    stop("Package 'patchwork' is required.")
  }
  if (!requireNamespace("fields", quietly = TRUE)) {
    stop("Package 'fields' is required.")
  }
  if (!requireNamespace("viridis", quietly = TRUE)) {
    stop("Package 'viridis' is required.")
  }
  if (!requireNamespace("scales", quietly = TRUE)) {
    stop("Package 'scales' is required.")
  }

  if (!is.list(scc)) {
    stop("'scc' must be a list-like SCC object.")
  }
  if (is.null(scc$Z) || is.null(scc$ind.inside.cover) || is.null(scc$scc) || is.null(scc$Yhat)) {
    stop("'scc' must contain 'Z', 'ind.inside.cover', 'scc', and 'Yhat'.")
  }

  Z <- scc$Z[scc$ind.inside.cover, , drop = FALSE]
  lower <- scc$scc[, 1, 2]
  upper <- scc$scc[, 2, 2]
  mean_est <- scc$Yhat[1, ]

  if (ncol(Z) < 2) {
    stop("'scc$Z' must contain at least two coordinate columns.")
  }
  if (length(lower) != nrow(Z) || length(upper) != nrow(Z) || length(mean_est) != nrow(Z)) {
    stop("Mismatch between SCC values and coordinates.")
  }

  if (is.null(title)) {
    title <- "SCC FOR GROUP 1"
  }

  x_dim <- max(Z[, 1], na.rm = TRUE)
  y_dim <- max(Z[, 2], na.rm = TRUE)
  x_lab <- paste0("Horizontal (0-", x_dim, ")")
  y_lab <- paste0("Longitudinal (0-", y_dim, ")")

  all_values <- c(lower, mean_est, upper)
  if (identical(zlim, "auto")) {
    zlim <- range(all_values, na.rm = TRUE)
  }

  palette_colors <- switch(
    palette,
    "nih" = fields::tim.colors(64),
    "viridis" = viridis::viridis(64),
    "gray" = grDevices::gray.colors(64),
    stop("Invalid palette. Choose one of: 'nih', 'viridis', 'gray'.")
  )

  fill_scale <- ggplot2::scale_fill_gradientn(
    colors = palette_colors,
    limits = zlim,
    oob = scales::squish,
    name = "value"
  )

  build_tile <- function(vals, label, title_x = NULL, title_y = NULL, show_legend = FALSE) {
    df <- data.frame(
      x = Z[, 1],
      y = Z[, 2],
      value = vals
    )

    ggplot2::ggplot(df, ggplot2::aes(x = x, y = y, fill = value)) +
      ggplot2::geom_tile(show.legend = show_legend) +
      fill_scale +
      ggplot2::coord_fixed() +
      ggplot2::labs(title = label, x = title_x, y = title_y) +
      ggplot2::theme_minimal(base_family = "serif") +
      ggplot2::theme(
        axis.title.x = if (!is.null(title_x)) {
          ggplot2::element_text(size = 12, margin = ggplot2::margin(t = 10))
        } else {
          ggplot2::element_blank()
        },
        axis.title.y = if (!is.null(title_y)) {
          ggplot2::element_text(size = 12, margin = ggplot2::margin(r = 10))
        } else {
          ggplot2::element_blank()
        },
        axis.text.x = ggplot2::element_text(size = 9),
        axis.text.y = ggplot2::element_text(size = 9),
        axis.ticks = ggplot2::element_line(linewidth = 0.2),
        plot.title = ggplot2::element_text(
          hjust = 0.5,
          size = 12,
          margin = ggplot2::margin(b = 5)
        )
      )
  }

  p1 <- build_tile(lower, "Lower Band", title_y = y_lab, show_legend = FALSE)
  p2 <- build_tile(mean_est, "Mean Estimate", title_x = x_lab, show_legend = TRUE)
  p3 <- build_tile(upper, "Upper Band", show_legend = FALSE)

  patchwork::wrap_plots(p1, p2, p3, nrow = 1, guides = "collect") +
    patchwork::plot_annotation(
      title = toupper(title),
      theme = ggplot2::theme(
        plot.title = ggplot2::element_text(
          family = "serif",
          face = "bold",
          size = 16,
          hjust = 0.5,
          margin = ggplot2::margin(b = 12)
        )
      )
    )
}

#' Evaluate SCC or SPM Detection Performance
#'
#' @description
#' Computes Sensitivity, Specificity, Positive Predictive Value (PPV), and Negative Predictive Value (NPV)
#' by comparing detected points with ground truth ROI points. This function is used to assess
#' the accuracy of SCC- or SPM-based detection in neuroimaging analysis.
#'
#' @param detectedPoints A data frame containing detected coordinates (\code{x}, \code{y}).
#'        SCC-detected points should be obtained using \code{\link{getPoints}}.
#'        SPM-detected points should be obtained using \code{\link{getSPMbinary}}.
#' @param truePoints A data frame with ground truth ROI coordinates (\code{x}, \code{y}),
#'        extracted via \code{\link{processROIs}}.
#' @param totalCoords A list with the full voxel grid dimensions, created by \code{\link{getDimensions}}.
#'        Must include named elements \code{xDim} and \code{yDim}.
#' @param regionName A character string used to label the output region.
#'
#' @return A data frame with the following evaluation metrics
#' \itemize{
#'   \item \code{region}: Name of the analyzed region.
#'   \item \code{sensitivity}: True positive rate (TP / (TP + FN) * 100).
#'   \item \code{specificity}: True negative rate (TN / (TN + FP) * 100).
#'   \item \code{PPV}: Positive predictive value (TP / (TP + FP) * 100).
#'   \item \code{NPV}: Negative predictive value (TN / (TN + FN) * 100).
#' }
#'
#' @details
#' This function requires three precomputed objects
#' \itemize{
#'   \item \code{detectedPoints}: SCC-detected points from \code{\link{getPoints}} or SPM-detected points from \code{\link{getSPMbinary}}.
#'   \item \code{truePoints}: Ground truth ROIs extracted using \code{\link{processROIs}}.
#'   \item \code{totalCoords}: Full voxel coordinate grid from \code{\link{getDimensions}}.
#' }
#'
#' @examples
#' # Load precomputed inputs for the example
#' data("calculateMetricsExample", package = "neuroSCC")
#'
#' # Evaluate SCC and SPM detection performance
#' with(calculateMetricsExample, {
#'   metricsSCC <- calculateMetrics(detectedSCC, trueROI, totalCoords, "Region2_SCC")
#'   metricsSPM <- calculateMetrics(detectedSPM, trueROI, totalCoords, "Region2_SPM")
#'
#'   print(metricsSCC)
#'   print(metricsSPM)
#' })
#'
#' @seealso
#' \code{\link{getPoints}} for SCC-detected regions. \cr
#' \code{\link{getSPMbinary}} for binary SPM-detected points. \cr
#' \code{\link{processROIs}} for defining ground truth ROIs. \cr
#' \code{\link{getDimensions}} for generating the coordinate grid.
#'
#' @export
#' @importFrom stats rpois
calculateMetrics <- function(detectedPoints, truePoints, totalCoords, regionName) {

  # 1. Validate Inputs
  # ---------------------------
  if (!is.character(regionName) || length(regionName) != 1) {
    stop("'regionName' must be a single character string.")
  }

  if (!all(c("x", "y") %in% colnames(detectedPoints))) {
    stop("'detectedPoints' must be a data frame with 'x' and 'y' columns.")
  }

  if (!all(c("x", "y", "pet") %in% colnames(truePoints))) {
    stop("'truePoints' must be a data frame containing 'x', 'y', and 'pet' columns.")
  }

  if (!all(c("xDim", "yDim") %in% names(totalCoords))) {
    stop("'totalCoords' must be a list containing 'xDim' and 'yDim'.")
  }

  # 2. Process Inputs
  # ---------------------------
  # Extract only voxels marked as ROI (pet = 1)
  truePoints <- subset(truePoints, pet == 1, select = c("x", "y"))

  # Generate total coordinate grid from getDimensions() output
  totalCoords <- expand.grid(x = 1:totalCoords$xDim, y = 1:totalCoords$yDim)

  # Merge x and y into a single identifier
  detectedPoints <- tidyr::unite(detectedPoints, "x_y", x, y, sep = "_", remove = FALSE)
  truePoints <- tidyr::unite(truePoints, "x_y", x, y, sep = "_", remove = FALSE)
  totalCoords <- tidyr::unite(totalCoords, "x_y", x, y, sep = "_", remove = FALSE)

  # 3. Compute True Positives, False Positives, False Negatives, and True Negatives
  # ---------------------------
  TP <- nrow(dplyr::inner_join(detectedPoints, truePoints, by = "x_y"))
  FP <- nrow(dplyr::setdiff(detectedPoints, truePoints))
  FN <- nrow(dplyr::setdiff(truePoints, detectedPoints))

  trueNegatives <- dplyr::setdiff(totalCoords, truePoints)
  detectedNegatives <- dplyr::setdiff(totalCoords, detectedPoints)
  TN <- nrow(dplyr::inner_join(trueNegatives, detectedNegatives, by = "x_y"))

  # 4. Compute Sensitivity, Specificity, PPV, and NPV
  # ---------------------------
  sensitivity <- if ((TP + FN) > 0) (TP / (TP + FN)) * 100 else NA
  specificity <- if ((TN + FP) > 0) (TN / (TN + FP)) * 100 else NA
  PPV <- if ((TP + FP) > 0) (TP / (TP + FP)) * 100 else NA
  NPV <- if ((TN + FN) > 0) (TN / (TN + FN)) * 100 else NA

  # 5. Return Results
  # ---------------------------
  result <- data.frame(
    region = regionName,
    sensitivity = sensitivity,
    specificity = specificity,
    PPV = PPV,
    NPV = NPV
  )

  return(result)
}

#' Clean and Load Data from NIfTI Neuroimaging Files
#'
#' @description
#' Loads a NIfTI-format neuroimaging file and transforms it into a structured data frame,
#' organizing voxel-level information for downstream analysis. This function is the first step
#' in the neuroimaging processing pipeline in \code{neuroSCC}, converting raw PET data into
#' a format suitable for functional data analysis. SCCs are later computed using functions
#' from the \code{ImageSCC} package, such as \code{ImageSCC::scc.image()}.
#'
#' @param name \code{character}. The full path to the NIfTI file to process.
#' @param demo Optional \code{data.frame} containing demographic information.
#'        If provided, it should include columns (case-insensitive): \code{PPT}, \code{Group}, \code{Sex}, and \code{Age}.
#'        If automatic matching via the \code{PPT} column fails, the row specified by \code{demoRow} is used. Default is \code{NULL}.
#' @param demoRow \code{integer}. Row to use from the demographic table if automatic matching fails. Default is \code{1}.
#'
#' @return A data frame where each row represents a voxel (3D pixel).
#' \itemize{
#'   \item If demographics are provided: the columns include \code{PPT}, \code{Group}, \code{Sex}, \code{Age}, \code{z}, \code{x}, \code{y}, and \code{pet}.
#'   \item If demographics are not provided: the columns include \code{z}, \code{x}, \code{y}, and \code{pet}.
#' }
#' The \code{pet} column contains the PET intensity value at each voxel location.
#'
#' @details
#' The function performs the following steps
#' \enumerate{
#'   \item Loads the NIfTI file using \code{oro.nifti::readNIfTI()}.
#'   \item Converts the 3D image into a tidy data frame.
#'   \item Adds \code{z}, \code{x}, and \code{y} voxel coordinates.
#'   \item If demographic data is provided, attempts to match based on \code{PPT} (case-insensitive). If no match is found, \code{demoRow} is used.
#' }
#'
#' The resulting data frame serves as input for \code{\link{databaseCreator}}, \code{\link{matrixCreator}},
#' and other core functions in the \code{neuroSCC} pipeline.
#'
#' @examples
#' # Load a sample Control NIfTI file
#' niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
#'
#' # Example Without demographic data
#' petData <- neuroCleaner(niftiFile)
#' petData[sample(nrow(petData), 10), ]  # Show 10 random voxels
#'
#' @seealso
#' \code{\link{databaseCreator}} for batch image processing. \cr
#' \code{\link[oro.nifti]{readNIfTI}} for reading NIfTI-format files.
#'
#' @export

neuroCleaner <- function(name, demo = NULL, demoRow = 1) {
  # 1. Input validation
  # ---------------------------
  # Check if name parameter is valid
  if (!is.character(name) || length(name) != 1) {
    stop("'name' must be a single character string specifying the file path")
  }

  # Check if the file exists
  if (!file.exists(name)) {
    stop("File not found: ", name)
  }

  # Check if demographic data is properly formatted (when provided)
  if (!is.null(demo)) {
    if (!is.data.frame(demo)) {
      stop("'demo' must be a data frame")
    }

    # Check for demographic columns case-insensitively
    demoCols <- tolower(names(demo))
    requiredCols <- c("ppt", "group", "sex", "age")

    if (!("ppt" %in% demoCols)) {
      warning("Demographic data doesn't contain 'PPT' column. Will use row ", demoRow, " instead.")
    }

    if (demoRow > nrow(demo)) {
      stop("'demoRow' (", demoRow, ") exceeds the number of rows in the demographic data (", nrow(demo), ")")
    }
  }

  # 2. Read NIFTI file
  # ---------------------------
  file <- tryCatch({
    oro.nifti::readNIfTI(
      fname = name,
      verbose = FALSE,
      warn = -1,
      reorient = TRUE,
      call = NULL,
      read_data = TRUE
    )
  }, error = function(e) {
    stop("Error reading NIFTI file: ", e$message)
  })

  # 3. Convert image data to data frame
  # ---------------------------
  n <- tryCatch({
    memisc::to.data.frame(oro.nifti::img_data(file))
  }, error = function(e) {
    stop("Error converting NIfTI data to data frame: ", e$message)
  })

  # 4. Extract dimensional information
  # ---------------------------
  dimensions <- neuroSCC::getDimensions(file)

  # Store file name without extension for demographic matching
  fileBaseName <- sub("\\.nii\\.gz$", "", basename(name))

  # Prepare empty data frame for storing the processed data
  dataframe <- data.frame(z = integer(), x = integer(), y = integer(), pet = numeric())

  # 5. Process each slice and organize data
  # ---------------------------
  for (i in seq_len(dimensions$xDim)) {
    nLim <- n[n$Var2 == i, ]
    nLim$Var1 <- NULL
    nLim$Var2 <- NULL

    z <- rep(i, length.out = dimensions$dim)
    x <- rep(1:dimensions$xDim, each = dimensions$yDim, length.out = dimensions$dim)
    y <- rep(1:dimensions$yDim, length.out = dimensions$dim)
    pet <- unlist(nLim)

    temp <- data.frame(z, x, y, pet)
    dataframe <- rbind(dataframe, temp)
  }

  # 6. Merge with demographic data (if provided)
  # ---------------------------
  if (!is.null(demo)) {
    # Helper function to retrieve column names case-insensitively
    getColumn <- function(colName) {
      idx <- which(tolower(names(demo)) == tolower(colName))
      if (length(idx) > 0) return(names(demo)[idx[1]])
      return(NULL)
    }

    pptColumn <- getColumn("ppt")

    # Ensure 'PPT' column is formatted correctly
    if (!is.null(pptColumn)) {
      demo[[pptColumn]] <- sub("\\.nii\\.gz$", "", demo[[pptColumn]])
    }

    # Try to match demographic data by PPT
    demographicData <- NULL
    if (!is.null(pptColumn)) {
      demographicData <- demo[demo[[pptColumn]] == fileBaseName, , drop = FALSE]
    }

    # If no match, fallback to demoRow selection
    if (is.null(demographicData) || nrow(demographicData) == 0) {
      if (!is.null(pptColumn)) {
        warning("No demographic data found for '", fileBaseName, "'. Using row ", demoRow, " instead.")
      }
      demographicData <- demo[demoRow, , drop = FALSE]
    }

    # Identify demographic columns
    groupColumn <- getColumn("group")
    sexColumn <- getColumn("sex")
    ageColumn <- getColumn("age")

    # Merge demographic data only if available
    if (nrow(demographicData) > 0) {
      demoData <- data.frame(
        PPT = rep(demographicData[[pptColumn]], each = nrow(dataframe)),
        Group = rep(demographicData[[groupColumn]], each = nrow(dataframe)),
        Sex = rep(demographicData[[sexColumn]], each = nrow(dataframe)),
        Age = rep(demographicData[[ageColumn]], each = nrow(dataframe))
      )
      dataframe <- cbind(demoData, dataframe)
    }
  }

  # 7. Reorder columns dynamically
  # ---------------------------
  columnOrder <- c("PPT", "Group", "Sex", "Age", "z", "x", "y", "pet")
  existingColumns <- intersect(columnOrder, names(dataframe))
  dataframe <- dataframe[, existingColumns]

  # 8. Return the processed data
  # ---------------------------
  return(dataframe)
}

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----eval=TRUE, echo=FALSE----------------------------------------------------
library(neuroSCC)

## -----------------------------------------------------------------------------

# Recreate necessary data from sample files
cat("Creating sample data for 2-group comparison...\n")

# Create databases for Control and Pathological groups
databaseControls <- databaseCreator(pattern = "^syntheticControl[12]\\.nii\\.gz$", control = TRUE, quiet = TRUE)
databasePathological <- databaseCreator(pattern = "^syntheticPathological[12]\\.nii\\.gz$", control = FALSE, quiet = TRUE)

# Create matrices suitable for SCC
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
matrixPathological <- matrixCreator(databasePathological, paramZ = 35, quiet = TRUE)

# Normalize matrices
normalizedControls <- meanNormalization(matrixControls)
normalizedPathological <- meanNormalization(matrixPathological)

# Extract contours from a control subject for SCC triangulation
niftiPath <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
contours <- neuroContour(niftiPath, paramZ = 35, plotResult = FALSE)

cat("Data preparation completed successfully.\n")


## -----------------------------------------------------------------------------

if (requireNamespace("ImageSCC", quietly = TRUE)) {
  message("'ImageSCC' package is available.")
} else {
  message("This vignette requires the 'ImageSCC' package.")
  message("You can install it from GitHub with:")
  message("  remotes::install_github('FIRST-Data-Lab/ImageSCC')")
}


## ----eval = requireNamespace("ImageSCC", quietly = TRUE), echo=TRUE-----------

# Check for Triangulation package
triangulation_available <- requireNamespace("Triangulation", quietly = TRUE)

if (triangulation_available) {
  message("'Triangulation' package is available.")
} else {
  message("'Triangulation' package not available.")
  message("Install with: remotes::install_github('FIRST-Data-Lab/Triangulation')")
}

# Proceed only if both packages are available
if (triangulation_available) {

  # Try loading precomputed SCC object from data/
  if (!exists("SCCcomp", inherits = FALSE) &&
      "SCCcomp" %in% data(package = "neuroSCC")$results[, "Item"]) {
    
    message("Loading precomputed SCC group comparison from package data...")
    suppressMessages(data("SCCcomp", package = "neuroSCC"))

  } else if (!exists("SCCcomp", inherits = FALSE)) {

    message("Precomputed data not found. Running SCC estimation...")

    # Perform SCC computation (only for development)
    SCCcomp <- ImageSCC::scc.image(
      Ya = normalizedPathological,
      Yb = normalizedControls,
      Z = contours[[1]],
      d.est = 5,
      d.band = 2,
      r = 1,
      V.est.a = as.matrix(contours[[1]]),
      Tr.est.a = as.matrix(contours[[1]]),
      V.band.a = as.matrix(contours[[1]]),
      Tr.band.a = as.matrix(contours[[1]]),
      penalty = TRUE,
      lambda = 10^{seq(-6, 3, 0.5)},
      alpha.grid = c(0.10, 0.05, 0.01),
      adjust.sigma = TRUE
    )
  }
}



## ----eval=TRUE----------------------------------------------------------------
if (!exists("SCCcomp", inherits = FALSE)) {
  data("SCCcomp", package = "neuroSCC")
}

## ----eval=TRUE, fig.alt="Two-group SCC comparison panel"----------------------
plotSCCcomparisonPanel(
  scc = SCCcomp,
  title = "SCC COMPARISON PANEL"
)

## ----eval=TRUE----------------------------------------------------------------
# Extract significant points from SCC results
significantPoints <- getPoints(SCCcomp)

# Load true ROI data provided within the package
roi_path <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
trueROI <- processROIs(roi_path, region = "Region2", number = "18", save = FALSE)

# Get total coordinate dimensions
dimensions <- getDimensions(roi_path)
totalCoords <- expand.grid(x = 1:dimensions$xDim, y = 1:dimensions$yDim)

# Calculate metrics to evaluate detection performance
metrics <- calculateMetrics(
  detectedPoints = significantPoints$positivePoints,
  truePoints = trueROI,
  totalCoords = dimensions,
  regionName = "Group_vs_Group"
)

# Display calculated metrics
print(metrics)

## ----eval=TRUE, fig.alt="Validation panel comparing ROI, SCC, and SPM detections"----
paramZ <- 35

controlPattern <- "^syntheticControl.*\\.nii\\.gz$"
databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
matrixCN <- meanNormalization(matrixCN)

roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))

spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)

plotValidationPanel(
  template = roiFile,
  backgroundMatrix = matrixCN,
  roiPoints = roiPoints,
  sccPoints = list(
    positivePoints = getPoints(SCCcomp)$positivePoints,
    negativePoints = data.frame(x = numeric(0), y = numeric(0))
  ),
  spmPoints = spmPoints,
  title = "Performance Validation Panel",
  label1 = "Ground Truth (ROI)",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)

#' Obtain neuroimaging contours from a NIFTI file
#'
#' @description
#' This function extracts contours from a neuroimaging NIFTI file by identifying
#' the boundary of the non-zero image support in a selected z-slice.
#' These contours serve as input for \code{Triangulation::TriMesh},
#' which is used in Simultaneous Confidence Corridors (SCCs) calculations.
#'
#' It is highly recommended that the input NIFTI file be pre-processed such that
#' zero values represent the background and non-zero values represent regions of interest.
#'
#' @param niftiFile \code{character}, the path to the NIFTI file containing neuroimaging data.
#'        Ideally, the file should be masked so that zero values represent the background.
#' @param paramZ \code{integer}, the specific z-slice to extract contours from. Default is \code{35}.
#' @param plotResult \code{logical}, if \code{TRUE}, plots the extracted contours. Default is \code{FALSE}.
#'
#' @return A \code{list} of data frames, where each data frame contains the x and y coordinates of a contour.
#' The first element typically represents the external boundary, while subsequent elements (if present)
#' represent internal contours or holes. Each data frame has two columns:
#' \itemize{
#'   \item \code{x} - x-coordinates of the contour points.
#'   \item \code{y} - y-coordinates of the contour points.
#' }
#'
#' @details
#' This function extracts contours from a \strong{NIFTI} file, typically a masked image where
#' background values are zero and regions of interest contain non-zero values.
#' Contours are computed from the boundary of the non-zero support of the selected slice.
#'
#' The extracted contours are typically used as input to \code{Triangulation::TriMesh}
#' to create a triangular mesh of the region, which is then used for
#' Simultaneous Confidence Corridors calculations.
#'
#' @examples
#' # Get the file path for a sample NIfTI file
#' niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
#'
#' # Extract contours from the non-zero support
#' contours <- neuroContour(niftiFile, paramZ = 35, plotResult = TRUE)
#'
#' # Display the first few points of the main contour
#' head(contours[[1]])
#'
#' @seealso
#' \code{Triangulation::TriMesh} for the next step in the SCC calculation process.
#'
#' @export
#' @importFrom graphics points
neuroContour <- function(niftiFile, paramZ = 35, plotResult = FALSE) {
  # 1. Input validation
  # ---------------------------
  # Check if niftiFile is a valid file path
  if (!is.character(niftiFile) || length(niftiFile) != 1) {
    stop("'niftiFile' must be a single character string specifying the file path")
  }

  if (!file.exists(niftiFile)) {
    stop("File not found: ", niftiFile)
  }

  # Check if paramZ is an integer
  if (!is.numeric(paramZ) || length(paramZ) != 1 || paramZ <= 0) {
    stop("'paramZ' must be a positive integer specifying the slice number")
  }

  # Check if plotResult is logical
  if (!is.logical(plotResult) || length(plotResult) != 1) {
    stop("'plotResult' must be a single logical value (TRUE or FALSE)")
  }

  # 2. Process NIFTI file with neuroCleaner
  # ---------------------------
  template <- neuroSCC::neuroCleaner(niftiFile)

  # Extract specific z-slice
  template <- subset(template, template$z == paramZ)

  if (nrow(template) == 0) {
    stop("No data found for the specified z-slice: ", paramZ)
  }

  # Get image dimensions
  xMax <- max(template$x)
  yMax <- max(template$y)
  xyTotal <- xMax * yMax

  # Convert PET values to a matrix format
  templateValues <- t(as.matrix(template[, "pet"]))
  templateValues[is.nan(templateValues)] <- 0

  # Create coordinate grid
  xCoords <- rep(1:xMax, each = yMax, length.out = xyTotal)
  yCoords <- rep(1:yMax, length.out = xyTotal)
  coordinates <- cbind(as.matrix(xCoords), as.matrix(yCoords))

  # Combine into a formatted data frame
  dat <- as.data.frame(cbind(coordinates, t(templateValues)))
  names(dat) <- c("x", "y", "value")
  dat[is.na(dat)] <- 0
  rownames(dat) <- NULL

  # 3. Contour extraction
  # ---------------------------
  coord <- tryCatch({
    .extract_mask_contours(dat, contour_level = 0.1)
  }, error = function(e) {
    stop("Error extracting contours: ", e$message)
  })

  # Check if contours were found
  if (length(coord) == 0) {
    warning("No contours found. Returning empty list.")
    return(list())
  }

  # 5. Optional plotting
  # ---------------------------
  if (plotResult && length(coord) > 0) {
    plot(coord[[1]], type = "l", xlab = "x", ylab = "y", main = "Extracted Contours")

    # Add any internal contours (holes)
    if (length(coord) > 1) {
      for (j in 2:length(coord)) {
        points(coord[[j]])
      }
    }
  }

  # 6.   Ensure plotting works even when assigned to an object
  # ---------------------------
  if (plotResult) {
    return(invisible(coord))  # Prevents suppression of plots while allowing assignment
  }

  return(coord)
}

#' Convert Database to Functional Data Matrix Format
#'
#' @description
#' Converts a PET image database (created via \code{\link{databaseCreator}}) into
#' a matrix format suitable for functional data analysis.
#' Each row of the resulting matrix corresponds to a subject, and each column to a voxel's PET intensity
#' values at a specified brain slice.
#'
#' @param database A data frame created by \code{\link{databaseCreator}}, containing
#'        voxel-level PET image data, including subject identifiers, coordinates, and intensity values.
#' @param paramZ An integer specifying the z-coordinate (slice) to extract. Default is \code{35}.
#' @param useSequentialNumbering \code{logical}. If \code{TRUE}, assigns sequential subject IDs
#'        instead of extracting them from filenames. Not currently used inside this function. Default is \code{FALSE}.
#' @param quiet \code{logical}. If \code{TRUE}, suppresses progress messages. Default is \code{FALSE}.
#'
#' @return A numeric matrix where
#' \itemize{
#'   \item Each row represents one subject's PET values at the selected z-slice.
#'   \item Each column corresponds to a voxel (flattened as a 1D row).
#' }
#'
#' @details
#' This function performs the following steps
#' \enumerate{
#'   \item Verifies that the specified z-slice exists in the database.
#'   \item Identifies the correct subject grouping column (\code{CN_number} or \code{AD_number}).
#'   \item Determines the matrix dimensions using \code{x} and \code{y} coordinates.
#'   \item Extracts PET intensities per subject at the given slice.
#'   \item Replaces any \code{NaN} values with \code{0} to ensure numerical stability.
#' }
#'
#' This function typically follows \code{\link{databaseCreator}} and precedes
#' \code{\link{meanNormalization}} in the neuroSCC workflow.
#'
#' @examples
#' # NOTE: To keep example runtime short, only one synthetic PET file is used.
#' # For full analysis, expand the filename pattern accordingly.
#'
#' # Step 1: Generate a database for a single subject
#' controlPattern <- "^syntheticControl1\\.nii\\.gz$"
#' databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
#'
#' # Step 2: Convert the database into a matrix format
#' matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
#'
#' # Display dimensions of the matrix
#' dim(matrixControls)
#'
#' @seealso
#' \code{\link{databaseCreator}} for generating the input database. \cr
#' \code{\link{meanNormalization}} for scaling matrix data prior to SCC computation.
#'
#' @export
matrixCreator <- function(database, paramZ = 35, useSequentialNumbering = FALSE, quiet = FALSE) {
  # 1. Input validation
  if (!is.data.frame(database)) {
    stop("'database' must be a data frame created by databaseCreator")
  }

  # Validate z-slice exists
  zValues <- unique(database$z)
  if (!(paramZ %in% zValues)) {
    stop(sprintf("Specified z-slice %d not found. Available z-slices: %s",
                 paramZ, paste(zValues, collapse = ", ")))
  }

  # 2. Determine group identification
  if ("CN_number" %in% colnames(database)) {
    groupCol <- "CN_number"
  } else if ("AD_number" %in% colnames(database)) {
    groupCol <- "AD_number"
  } else {
    stop("Database must contain either 'CN_number' or 'AD_number' column")
  }

  # 3. Calculate matrix dimensions
  zSliceData <- subset(database, z == paramZ)
  xMax <- max(zSliceData$x)
  yMax <- max(zSliceData$y)
  matrixDim <- xMax * yMax

  # 4. Get unique subject numbers
  subjectNumbers <- unique(database[[groupCol]])

  # 5. Preallocate the matrix
  matrixResult <- matrix(nrow = length(subjectNumbers), ncol = matrixDim)

  # 6. Process each subject
  for (i in seq_along(subjectNumbers)) {
    subjectID <- subjectNumbers[i]

    # Print progress if not quiet
    if (!quiet) {
      message(sprintf("Processing Subject %s", subjectID))
    }

    # Extract PET values for the subject at the specified z-slice
    subsetData <- database[database[[groupCol]] == subjectID & database$z == paramZ, ]
    Y <- ifelse(is.nan(subsetData$pet), 0, subsetData$pet)

    # Assign to matrix row
    matrixResult[i, ] <- as.numeric(Y)
  }

  return(matrixResult)
}

#' Mean Normalization for Matrix Data
#'
#' @description
#' Normalizes each row of a matrix by dividing its elements by the row mean, ignoring \code{NA} values.
#' This step is commonly used to adjust for global intensity differences across subjects before
#' applying statistical comparisons or functional data analysis.
#'
#' @param matrixData A \code{matrix} where each row represents one subject’s PET data,
#'        typically generated by \code{\link{matrixCreator}}.
#' @param handleInvalidRows \code{character}. Specifies how to handle rows with invalid means (either zero or \code{NA}).
#'        Options include \code{"warn"} (default), \code{"error"}, or \code{"omit"}.
#' @param returnDetails \code{logical}. If \code{TRUE}, returns a list with the normalized matrix and
#'        additional diagnostics. If \code{FALSE} (default), returns only the normalized matrix.
#' @param quiet \code{logical}. If \code{TRUE}, suppresses console messages. Default is \code{FALSE}.
#'
#' @return A normalized matrix, or a list if \code{returnDetails = TRUE}.
#' \itemize{
#'   \item \code{normalizedMatrix} – The normalized matrix.
#'   \item \code{problemRows} – Indices of rows that had zero or \code{NA} means.
#' }
#'
#' @details
#' The function performs the following steps
#' \enumerate{
#'   \item Computes the row means of the input matrix, ignoring \code{NA}s.
#'   \item Divides each row by its corresponding mean.
#'   \item Replaces \code{NaN} values (from division by 0) with \code{0} if applicable.
#'   \item Handles problematic rows according to the selected \code{handleInvalidRows} option:
#'         \code{"warn"} (default) issues a warning, \code{"error"} stops execution,
#'         and \code{"omit"} removes the affected rows from the result.
#' }
#'
#' This step is often used prior to applying SCC methods to ensure comparability across subjects.
#'
#' @examples
#' # Generate a minimal database and create a matrix (1 control subject)
#' dataDir <- system.file("extdata", package = "neuroSCC")
#' controlPattern <- "^syntheticControl1\\.nii\\.gz$"
#' databaseControls <- databaseCreator(pattern = controlPattern,
#'                                     control = TRUE,
#'                                     quiet = TRUE)
#' matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
#'
#' # Normalize the matrix (with diagnostics)
#' normalizationResult <- meanNormalization(matrixControls,
#'                                          returnDetails = TRUE,
#'                                          quiet = FALSE)
#'
#' @seealso
#' \code{\link{matrixCreator}} for building the matrix input to normalize.
#'
#' @export
meanNormalization <- function(matrixData,
                              handleInvalidRows = c("warn", "error", "omit"),
                              returnDetails = FALSE,
                              quiet = FALSE) {
  # 1. Input validation
  if (!is.matrix(matrixData)) {
    stop("'matrixData' must be a matrix")
  }

  if (nrow(matrixData) == 0) {
    warning("Empty matrix provided. Returning unchanged.")
    return(matrixData)
  }

  handleInvalidRows <- match.arg(handleInvalidRows)

  # 2. Calculate row means, ignoring NA values
  rowMeansBefore <- rowMeans(matrixData, na.rm = TRUE)
  overallMeanBefore <- mean(rowMeansBefore, na.rm = TRUE)

  if (!quiet) {
    cat(sprintf("\n Mean before normalization: %.6f\n", overallMeanBefore))
  }

  # Identify problem rows (zero mean or NA mean)
  problemRows <- which(is.na(rowMeansBefore) | rowMeansBefore == 0)

  if (length(problemRows) > 0) {
    if (handleInvalidRows == "error") {
      stop("Some rows have an invalid mean (zero or NA). Processing halted.")
    } else if (handleInvalidRows == "warn") {
      warning("Some rows have an invalid mean and were left unnormalized.")
    }
  }

  # Normalize the matrix, handling problematic rows
  normalizedMatrix <- matrixData / rowMeansBefore

  if (handleInvalidRows == "omit") {
    normalizedMatrix <- normalizedMatrix[-problemRows, , drop = FALSE]
  }

  # 3. Calculate new mean after normalization
  rowMeansAfter <- rowMeans(normalizedMatrix, na.rm = TRUE)
  overallMeanAfter <- mean(rowMeansAfter, na.rm = TRUE)

  if (!quiet) {
    cat(sprintf("\n Normalization completed."))
  }

  # 4. Return results
  if (returnDetails) {
    return(list(
      normalizedMatrix = normalizedMatrix,
      problemRows = problemRows
    ))
  } else {
    return(normalizedMatrix)
  }
}

#' Wrappers for Neuroimaging Functional Data Preparation and SCC Analysis
#'
#' @description
#' The \code{neuroSCC} package provides tools to preprocess and structure neuroimaging data
#' for functional data analysis using Simultaneous Confidence Corridors (SCCs). It wraps external packages
#' to prepare data from PET images, extract contours, generate meshes, and evaluate regions of statistical significance.
#'
#' The methods implemented support both group comparisons and single-subject vs. group inference,
#' following the methodology described in Wang et al. (2020) and the author's PhD thesis.
#'
#' @details
#' This package serves as a bridge between neuroimaging file formats (e.g., NIfTI) and advanced
#' statistical tools like \code{ImageSCC::scc.image}. It includes the following key components.
#' \itemize{
#'   \item Loading and cleaning PET image data.
#'   \item Extracting ROIs and constructing functional data matrices.
#'   \item Generating synthetic Poisson clones for 1-vs-group settings.
#'   \item Extracting SCC-detected points and evaluating detection metrics.
#' }
#'
#' @docType package
#' @name neuroSCC-package
#' @aliases neuroSCC
#' @seealso \code{\link{neuroCleaner}}, \code{\link{databaseCreator}}, \code{\link{getPoints}}
"_PACKAGE"

#' Plot group means and SCC comparison overlay
#'
#' @description
#' This function visualizes a two-group Simultaneous Confidence Corridor (SCC)
#' result as a three-panel figure showing the mean estimate for each group and
#' an overlay panel with SCC-detected differences.
#'
#' @param scc A list-like SCC result object, typically returned by
#'   \code{ImageSCC::scc.image()}, containing the components required for
#'   plotting group means and SCC-derived significant points.
#' @param title \code{character}, title shown above the panel. If \code{NULL},
#'   the default title is \code{"SCC COMPARISON PANEL"}.
#' @param zlim Either \code{"auto"} to compute color limits from the plotted values,
#'   or a numeric vector of length 2 specifying the lower and upper limits of the
#'   fill scale.
#' @param palette \code{character}, color palette used in the mean heatmaps.
#'   Supported values are \code{"nih"}, \code{"viridis"}, and \code{"gray"}.
#' @param label1 \code{character}, title of the first group panel.
#' @param label2 \code{character}, title of the second group panel.
#' @param label3 \code{character}, title of the SCC overlay panel.
#' @param overlay \code{character}, which SCC-detected points to overlay in the
#'   third panel. Supported values are \code{"positive"}, \code{"negative"},
#'   \code{"both"}, and \code{"none"}.
#' @param useRawMeans \code{logical}, if \code{TRUE}, the group means are computed
#'   directly from \code{scc$Ya} and \code{scc$Yb}. If \code{FALSE}, the function
#'   uses \code{scc$Yhat}.
#'
#' @return A patchwork/ggplot object containing three aligned panels:
#' \itemize{
#'   \item mean estimate for group 1,
#'   \item mean estimate for group 2,
#'   \item SCC overlay panel with detected positive and/or negative points.
#' }
#'
#' @details
#' The first two panels use a shared continuous color scale to facilitate direct
#' comparison between group mean estimates. The third panel uses a grayscale
#' background and overlays SCC-detected significant points.
#'
#' Positive and negative SCC detections are obtained internally using
#' \code{\link{getPoints}}.
#'
#' @examples
#' data("SCCcomp", package = "neuroSCC")
#' plotSCCcomparisonPanel(SCCcomp, title = "SCC COMPARISON PANEL")
#'
#' @seealso
#' \code{\link{SCCcomp}} for the example two-group SCC object used in the examples. \cr
#' \code{\link{getPoints}} for extraction of SCC-detected significant points. \cr
#' \code{\link{plotSCCpanel}} for single-group SCC visualization. \cr
#' \code{\link{plotValidationPanel}} for SCC versus SPM performance visualization.
#'
#' @export
plotSCCcomparisonPanel <- function(scc,
                                   title = NULL,
                                   zlim = "auto",
                                   palette = "nih",
                                   label1 = "Group 1 Mean",
                                   label2 = "Group 2 Mean",
                                   label3 = "SCC Overlay",
                                   overlay = c("positive", "negative", "both", "none"),
                                   useRawMeans = FALSE) {
  if (!requireNamespace("ggplot2", quietly = TRUE)) {
    stop("Package 'ggplot2' is required.")
  }
  if (!requireNamespace("patchwork", quietly = TRUE)) {
    stop("Package 'patchwork' is required.")
  }
  if (!requireNamespace("fields", quietly = TRUE)) {
    stop("Package 'fields' is required.")
  }
  if (!requireNamespace("viridis", quietly = TRUE)) {
    stop("Package 'viridis' is required.")
  }
  if (!requireNamespace("scales", quietly = TRUE)) {
    stop("Package 'scales' is required.")
  }

  overlay <- match.arg(overlay)

  if (!is.list(scc)) {
    stop("'scc' must be a list-like SCC object.")
  }

  if (!is.null(scc$Yhat) && !useRawMeans) {
    if (is.null(scc$Z) || is.null(scc$ind.inside.cover)) {
      stop("'scc' must contain 'Z' and 'ind.inside.cover'.")
    }
    Z <- scc$Z[scc$ind.inside.cover, , drop = FALSE]
    mean1_vals <- scc$Yhat[1, ]
    mean2_vals <- scc$Yhat[2, ]
  } else {
    if (is.null(scc$Z.band) || is.null(scc$Ya) || is.null(scc$Yb)) {
      stop("'scc' must contain 'Z.band', 'Ya', and 'Yb' when 'useRawMeans = TRUE'.")
    }
    Z <- scc$Z.band
    mean1_vals <- colMeans(scc$Ya)
    mean2_vals <- colMeans(scc$Yb)
  }

  if (ncol(Z) < 2) {
    stop("'scc' coordinates must contain at least two columns.")
  }
  if (length(mean1_vals) != nrow(Z) || length(mean2_vals) != nrow(Z)) {
    stop("Mismatch between SCC values and coordinates.")
  }

  df1 <- data.frame(x = Z[, 1], y = Z[, 2], value = mean1_vals)
  df2 <- data.frame(x = Z[, 1], y = Z[, 2], value = mean2_vals)
  df3 <- df2

  overlay_pts <- getPoints(scc)
  pos_pts <- overlay_pts$positivePoints
  neg_pts <- overlay_pts$negativePoints

  x_dim <- max(Z[, 1], na.rm = TRUE)
  y_dim <- max(Z[, 2], na.rm = TRUE)
  x_lab <- paste0("Horizontal (0-", x_dim, ")")
  y_lab <- paste0("Longitudinal (0-", y_dim, ")")

  if (is.null(title)) {
    title <- "SCC COMPARISON PANEL"
  }

  palette_colors <- switch(
    palette,
    "nih" = fields::tim.colors(64),
    "viridis" = viridis::viridis(64),
    "gray" = grDevices::gray.colors(64),
    stop("Invalid palette. Choose one of: 'nih', 'viridis', 'gray'.")
  )

  all_values <- c(df1$value, df2$value)
  if (identical(zlim, "auto")) {
    zlim <- range(all_values, na.rm = TRUE)
  }

  fill_scale <- ggplot2::scale_fill_gradientn(
    colors = palette_colors,
    limits = zlim,
    oob = scales::squish,
    name = "value"
  )

  build_tile <- function(df, label, title_x = NULL, title_y = NULL,
                         show_legend = FALSE, scale = fill_scale) {
    ggplot2::ggplot(df, ggplot2::aes(x = x, y = y, fill = value)) +
      ggplot2::geom_tile(show.legend = show_legend) +
      scale +
      ggplot2::coord_fixed() +
      ggplot2::labs(title = label, x = title_x, y = title_y) +
      ggplot2::theme_minimal(base_family = "serif") +
      ggplot2::theme(
        axis.title.x = if (!is.null(title_x)) {
          ggplot2::element_text(size = 12, margin = ggplot2::margin(t = 10))
        } else {
          ggplot2::element_blank()
        },
        axis.title.y = if (!is.null(title_y)) {
          ggplot2::element_text(size = 12, margin = ggplot2::margin(r = 10))
        } else {
          ggplot2::element_blank()
        },
        axis.text.x = ggplot2::element_text(size = 9),
        axis.text.y = ggplot2::element_text(size = 9),
        axis.ticks = ggplot2::element_line(linewidth = 0.2),
        plot.title = ggplot2::element_text(
          hjust = 0.5,
          size = 12,
          margin = ggplot2::margin(b = 5)
        )
      )
  }

  p1 <- build_tile(df1, label1, title_y = y_lab, show_legend = FALSE)
  p2 <- build_tile(df2, label2, title_x = x_lab, show_legend = TRUE)

  gray_scale <- ggplot2::scale_fill_gradient(low = "black", high = "white", name = NULL)
  p3 <- build_tile(df3, label3, show_legend = FALSE, scale = gray_scale)

  if (overlay %in% c("positive", "both") && nrow(pos_pts) > 0) {
    p3 <- p3 + ggplot2::geom_point(
      data = pos_pts,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "blue",
      size = 1.2,
      shape = 15
    )
  }

  if (overlay %in% c("negative", "both") && nrow(neg_pts) > 0) {
    p3 <- p3 + ggplot2::geom_point(
      data = neg_pts,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "red",
      size = 1.2,
      shape = 17
    )
  }

  patchwork::wrap_plots(p1, p2, p3, nrow = 1, guides = "collect") +
    patchwork::plot_annotation(
      title = toupper(title),
      theme = ggplot2::theme(
        plot.title = ggplot2::element_text(
          family = "serif",
          face = "bold",
          size = 16,
          hjust = 0.5,
          margin = ggplot2::margin(b = 12)
        )
      )
    )
}

#' Extract Significant SCC Points from an SCC Comparison Object
#'
#' @description
#' Identifies and extracts coordinates where differences fall outside the simultaneous confidence corridors (SCCs),
#' indicating statistically significant regions. This function processes the results from
#' \code{ImageSCC::scc.image()} and returns the voxel locations that represent either hypo- or hyperactivity.
#'
#' Interpretation depends on the order of inputs in the SCC computation.
#' If SCC was computed as \code{scc.image(Ya = Y_AD, Yb = Y_CN, ...)} (i.e., the Control group is the second argument).
#'
#' \itemize{
#'   \item \code{positivePoints} — Regions where Control minus Pathological is significantly above the SCC.
#'     These correspond to areas where the Pathological group (AD) is \emph{hypoactive} relative to Controls.
#'   \item \code{negativePoints} — Regions where Control minus Pathological is significantly below the SCC.
#'     These correspond to areas where the Pathological group is \emph{hyperactive} relative to Controls.
#' }
#'
#' \strong{Always confirm the order of \code{Ya} and \code{Yb} in the SCC computation}
#' to interpret the directionality correctly.
#'
#' @param sccResult A list of SCC computation results, as returned by \code{ImageSCC::scc.image}.
#' Must include the following components
#' \itemize{
#'   \item \code{Z.band} — A matrix specifying grid positions.
#'   \item \code{ind.inside.cover} — Indices of grid points within the confidence band.
#'   \item \code{scc} — A 3D array containing the computed SCC values.
#' }
#'
#' @return A named list with two elements
#' \itemize{
#'   \item \code{positivePoints} — A data frame with coordinates where the \strong{first group (Ya)} shows
#'         significantly lower activity than the \strong{second group (Yb)}.
#'   \item \code{negativePoints} — A data frame with coordinates where the \strong{first group (Ya)} shows
#'         significantly higher activity than the \strong{second group (Yb)}.
#' }
#'
#' @examples
#' # Load precomputed SCC example
#' data("SCCcomp", package = "neuroSCC")
#'
#' # Extract significant SCC points
#' significantPoints <- getPoints(SCCcomp)
#'
#' # Show extracted points (interpretation depends on SCC setup; see description)
#' head(significantPoints$positivePoints)  # Pathological hypoactive vs. Control
#' head(significantPoints$negativePoints)  # Pathological hyperactive vs. Control
#'
#' @seealso
#' \code{ImageSCC::scc.image} for SCC computation.
#'
#' @export
getPoints <- function(sccResult) {
  # 1. Validate Input
  # ---------------------------
  if (!is.list(sccResult)) {
    stop("'sccResult' must be a list containing SCC comparison results.")
  }

  required_elements <- c("Z.band", "ind.inside.cover", "scc")
  missing_elements <- setdiff(required_elements, names(sccResult))
  if (length(missing_elements) > 0) {
    stop("Missing required elements in SCC object: ", paste(missing_elements, collapse = ", "))
  }

  # Extract required components
  Z.band <- matrix(sccResult$Z.band, ncol = 2)  # Grid positions
  insideCover <- sccResult$ind.inside.cover     # Indices inside the SCC region
  sccValues <- sccResult$scc                    # SCC values (3D array)

  # 2. Ensure SCC Data is Valid
  # ---------------------------
  if (is.null(sccValues) || all(is.na(sccValues))) {
    warning("SCC values are empty or contain only NA values. Returning empty results.")
    return(list(positivePoints = data.frame(x = numeric(), y = numeric()),
                negativePoints = data.frame(x = numeric(), y = numeric())))
  }

  # Get unique grid positions
  z1 <- unique(Z.band[, 1])
  z2 <- unique(Z.band[, 2])
  n1 <- length(z1)
  n2 <- length(z2)

  # 3. Create SCC Matrices
  # ---------------------------
  # Initialize SCC matrices
  scc <- matrix(NA, n1 * n2, 2)

  # Ensure proper alignment when assigning SCC values
  if (length(insideCover) != nrow(sccValues)) {
    stop("Mismatch: 'ind.inside.cover' length does not match SCC matrix size.")
  }

  scc[insideCover, ] <- sccValues[, , 2]  # Assign SCC confidence band values

  # Define SCC thresholds
  sccLower <- matrix(scc[, 1], nrow = n2, ncol = n1)  # Lower bound (negative SCC threshold)
  sccUpper <- matrix(scc[, 2], nrow = n2, ncol = n1)  # Upper bound (positive SCC threshold)

  # Keep only values that fall outside the SCC region:

  # If the lower bound is negative, it means the difference is too high (Control > AD),
  # so we keep only positive values.
  sccLower[sccLower < 0] <- NA  # Retain only significant positive deviations (Control > AD)

  # If the upper bound is positive, it means the difference is too low (AD > Control),
  #so we keep only negative values.
  sccUpper[sccUpper > 0] <- NA  # Retain only significant negative deviations (AD > Control)

  # 4. Identify Significant SCC Points
  # ---------------------------
  posPoints <- which(sccLower > 0, arr.ind = TRUE)  # First group stronger
  negPoints <- which(sccUpper < 0, arr.ind = TRUE)  # Second group stronger

  # 5. Convert Indexes to Coordinates
  # ---------------------------
  positiveCoords <- if (nrow(posPoints) > 0) {
    data.frame(x = z1[posPoints[, 2]], y = z2[posPoints[, 1]])
  } else {
    data.frame(x = numeric(), y = numeric())
  }

  negativeCoords <- if (nrow(negPoints) > 0) {
    data.frame(x = z1[negPoints[, 2]], y = z2[negPoints[, 1]])
  } else {
    data.frame(x = numeric(), y = numeric())
  }

  # Return structured results
  return(list(positivePoints = positiveCoords, negativePoints = negativeCoords))
}

#' Plot ROI, SCC detections, and SPM detections for validation
#'
#' @description
#' This function visualizes the ground-truth ROI, SCC-detected points,
#' and SPM-detected points as a three-panel comparison over a shared
#' neuroimaging background.
#'
#' @param template \code{character}, path to a NIfTI file used to obtain the
#'   grid dimensions of the imaging domain.
#' @param backgroundMatrix A numeric matrix used to generate the grayscale
#'   background image.
#' @param roiPoints A \code{data.frame} with columns \code{x} and \code{y}
#'   containing the ground-truth ROI points.
#' @param sccPoints A list containing \code{positivePoints} and
#'   \code{negativePoints}, each as a \code{data.frame} with columns
#'   \code{x} and \code{y}.
#' @param spmPoints A \code{data.frame} with columns \code{x} and \code{y}
#'   containing the SPM-detected points.
#' @param title \code{character}, title shown above the panel.
#' @param label1 \code{character}, title of the ground-truth ROI panel.
#' @param label2 \code{character}, title of the SCC-detected panel.
#' @param label3 \code{character}, title of the SPM-detected panel.
#'
#' @return A patchwork/ggplot object containing three aligned panels:
#' \itemize{
#'   \item ground-truth ROI,
#'   \item SCC-detected points,
#'   \item SPM-detected points.
#' }
#'
#' @details
#' The three panels share the same grayscale background to facilitate visual
#' comparison between the true ROI and the points detected by SCC and SPM.
#'
#' In the examples, SCC detections are restricted to positive points only
#' to keep the visualization simple. With real analysis outputs,
#' \code{sccPoints} would typically be supplied directly as
#' \code{getPoints(<SCC object>)}.
#'
#' @examples
#' \donttest{
#' paramZ <- 35
#'
#' controlPattern <- "^syntheticControl.*\\.nii\\.gz$"
#' databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
#' matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
#' matrixCN <- meanNormalization(matrixCN)
#'
#' roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
#' truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
#' roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))
#'
#' spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
#' spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)
#'
#' data("SCCcomp", package = "neuroSCC")
#'
#' plotValidationPanel(
#'   template = roiFile,
#'   backgroundMatrix = matrixCN,
#'   roiPoints = roiPoints,
#'   sccPoints = list(
#'     positivePoints = getPoints(SCCcomp)$positivePoints,
#'     negativePoints = data.frame(x = numeric(0), y = numeric(0))
#'   ),
#'   spmPoints = spmPoints,
#'   title = "Performance Validation Panel",
#'   label1 = "Ground Truth (ROI)",
#'   label2 = "SCC Detected",
#'   label3 = "SPM Detected"
#' )
#' }
#'
#' @seealso
#' \code{\link{SCCcomp}} for the example SCC object used in the examples. \cr
#' \code{\link{getPoints}} for extraction of SCC-detected significant points. \cr
#' \code{\link{getSPMbinary}} for extraction of SPM-detected significant points. \cr
#' \code{\link{processROIs}} for extraction of ground-truth ROI points.
#'
#' @export
plotValidationPanel <- function(template,
                                backgroundMatrix,
                                roiPoints,
                                sccPoints,
                                spmPoints,
                                title = "COMPARISON PANEL",
                                label1 = "True ROI",
                                label2 = "SCC Detected",
                                label3 = "SPM Detected") {
  if (!requireNamespace("ggplot2", quietly = TRUE)) {
    stop("Package 'ggplot2' is required.")
  }
  if (!requireNamespace("patchwork", quietly = TRUE)) {
    stop("Package 'patchwork' is required.")
  }

  if (!is.character(template) || length(template) != 1) {
    stop("'template' must be a single character string with the path to a NIfTI file.")
  }
  if (!file.exists(template)) {
    stop("File not found: ", template)
  }
  if (!is.matrix(backgroundMatrix)) {
    stop("'backgroundMatrix' must be a matrix.")
  }
  if (!is.data.frame(roiPoints) || !all(c("x", "y") %in% names(roiPoints))) {
    stop("'roiPoints' must be a data.frame with columns 'x' and 'y'.")
  }
  if (!is.list(sccPoints) ||
      is.null(sccPoints$positivePoints) ||
      is.null(sccPoints$negativePoints)) {
    stop("'sccPoints' must be a list containing 'positivePoints' and 'negativePoints'.")
  }
  if (!is.data.frame(spmPoints) || !all(c("x", "y") %in% names(spmPoints))) {
    stop("'spmPoints' must be a data.frame with columns 'x' and 'y'.")
  }

  dims <- getDimensions(template)
  Z <- as.matrix(expand.grid(y = 1:dims$yDim, x = 1:dims$xDim)[, c(2, 1)])

  if (ncol(backgroundMatrix) != nrow(Z)) {
    stop("Mismatch between 'backgroundMatrix' and template dimensions.")
  }

  df_base <- data.frame(
    x = Z[, 1],
    y = Z[, 2],
    value = colMeans(backgroundMatrix)
  )

  x_lab <- paste0("Horizontal (0-", dims$xDim, ")")
  y_lab <- paste0("Longitudinal (0-", dims$yDim, ")")

  fill_scale <- ggplot2::scale_fill_gradient(
    low = "black",
    high = "white",
    name = NULL
  )

  base_theme <- ggplot2::theme_minimal(base_family = "serif") +
    ggplot2::theme(
      panel.background = ggplot2::element_rect(fill = "white", color = NA),
      plot.background = ggplot2::element_rect(fill = "white", color = NA),
      panel.grid = ggplot2::element_blank(),
      axis.text = ggplot2::element_text(size = 8, family = "serif"),
      axis.ticks = ggplot2::element_line(linewidth = 0.2),
      plot.title = ggplot2::element_text(
        hjust = 0.5,
        size = 11,
        face = "plain",
        family = "serif"
      ),
      legend.position = "none"
    )

  p1 <- ggplot2::ggplot(df_base, ggplot2::aes(x = x, y = y, fill = value)) +
    ggplot2::geom_tile() +
    fill_scale +
    ggplot2::geom_point(
      data = roiPoints,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "green",
      size = 1.2,
      shape = 15
    ) +
    ggplot2::coord_fixed() +
    ggplot2::labs(title = label1, x = NULL, y = y_lab) +
    base_theme +
    ggplot2::theme(
      axis.title.y = ggplot2::element_text(size = 11, margin = ggplot2::margin(r = 10))
    )

  p2 <- ggplot2::ggplot(df_base, ggplot2::aes(x = x, y = y, fill = value)) +
    ggplot2::geom_tile() +
    fill_scale +
    ggplot2::coord_fixed() +
    ggplot2::labs(title = label2, x = x_lab, y = NULL) +
    base_theme +
    ggplot2::theme(
      axis.title.x = ggplot2::element_text(size = 11, margin = ggplot2::margin(t = 10))
    )

  if (nrow(sccPoints$positivePoints) > 0) {
    p2 <- p2 + ggplot2::geom_point(
      data = sccPoints$positivePoints,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "blue",
      size = 1.2,
      shape = 15
    )
  }

  if (nrow(sccPoints$negativePoints) > 0) {
    p2 <- p2 + ggplot2::geom_point(
      data = sccPoints$negativePoints,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "red",
      size = 1.2,
      shape = 17
    )
  }

  p3 <- ggplot2::ggplot(df_base, ggplot2::aes(x = x, y = y, fill = value)) +
    ggplot2::geom_tile() +
    fill_scale +
    ggplot2::geom_point(
      data = spmPoints,
      ggplot2::aes(x = x, y = y),
      inherit.aes = FALSE,
      color = "blue",
      size = 1.2,
      shape = 15
    ) +
    ggplot2::coord_fixed() +
    ggplot2::labs(title = label3, x = NULL, y = NULL) +
    base_theme

  patchwork::wrap_plots(p1, p2, p3, nrow = 1) +
    patchwork::plot_annotation(
      title = toupper(title),
      theme = ggplot2::theme(
        plot.title = ggplot2::element_text(
          family = "serif",
          face = "bold",
          size = 16,
          hjust = 0.5,
          margin = ggplot2::margin(b = 12)
        )
      )
    )
}

#' Process ROI Voxel Data from a NIfTI File
#'
#' @description
#' Processes Regions of Interest (ROIs) from a binary NIfTI file by extracting voxel-level
#' coordinates and labeling each voxel as part of the ROI or not. The function preserves the
#' spatial structure and is typically used to prepare ground truth ROIs for comparison with
#' SCC-detected regions via \code{\link{calculateMetrics}}.
#'
#' @param roiFile \code{character}. Path to the binary NIfTI file containing ROI data.
#' @param region \code{character}. Name of the ROI region (e.g., \code{"Region2"}).
#' @param number \code{character}. Identifier for the subject or group (e.g., \code{"18"}).
#' @param save \code{logical}. If \code{TRUE}, saves the result as an \code{.RDS} file. If \code{FALSE},
#'        returns a data frame in the console. Default is \code{TRUE}.
#' @param outputDir \code{character}. Directory where the ROI table will be saved if \code{save = TRUE}.
#'        Default is a temporary file: \code{tempdir()}.
#' @param verbose \code{logical}. If \code{TRUE}, displays progress messages. Default is \code{TRUE}.
#'
#' @return A data frame with voxel-level ROI information.
#' \itemize{
#'   \item \code{group} – Combined identifier built from \code{region} and \code{number}.
#'   \item \code{z}, \code{x}, \code{y} – Voxel coordinates.
#'   \item \code{pet} – Binary value indicating ROI membership (\code{1} = ROI, \code{0} = non-ROI).
#' }
#' If \code{save = TRUE}, the data frame is saved as an \code{.RDS} file and not returned to the console.
#'
#' @details
#' The function uses \code{\link{neuroCleaner}} to load and flatten the NIfTI file into a structured
#' data frame. All voxels are retained, with the \code{pet} column indicating which ones are part
#' of the ROI (\code{1}) versus background (\code{0}). An ROI label is added in the \code{group} column.
#'
#' This output is used as ground truth for evaluating detection performance in SCC analyses.
#'
#' @examples
#' # Load and process a sample ROI NIfTI file (console output)
# roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
# processedROI <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
# head(processedROI)
#'
#' @seealso
#' \code{\link{calculateMetrics}} for evaluating SCC detection performance. \cr
#' \code{\link{neuroCleaner}} for reading and structuring voxel data.
#'
#' @export
processROIs <- function(roiFile,
                        region,
                        number,
                        save = TRUE,
                        outputDir = tempdir(),
                        verbose = TRUE) {

  # 1. Validate Inputs
  # ---------------------------
  if (!file.exists(roiFile)) stop("ROI file not found: ", roiFile)
  if (!is.character(region) || nchar(region) == 0) stop("region must be a non-empty string.")
  if (!is.character(number) || nchar(number) == 0) stop("number must be a non-empty string.")
  if (!is.logical(save) || length(save) != 1) stop("save must be TRUE or FALSE.")
  if (!is.logical(verbose) || length(verbose) != 1) stop("verbose must be TRUE or FALSE.")

  # 2. Load NIfTI File Using neuroCleaner
  # ---------------------------
  if (verbose) message("Loading NIfTI file...")
  voxelData <- neuroCleaner(roiFile)

  # 3. Assign ROI Group Identifier
  # ---------------------------
  voxelData$group <- paste0(region, "_number", number)

  # 4. Reorder Columns to Ensure group is First
  # ---------------------------
  columnOrder <- c("group", "z", "x", "y", "pet")
  voxelData <- voxelData[, columnOrder]

  # 5. Save or Print Results
  # ---------------------------
  if (save) {
    if (!dir.exists(outputDir)) dir.create(outputDir, recursive = TRUE)
    outputFile <- file.path(outputDir, paste0("ROItable_", region, "_", number, ".RDS"))
    saveRDS(voxelData, outputFile)
    if (verbose) message("ROI table saved to: ", outputFile)
  } else {
    return(voxelData)
  }
}

#' Extract SPM-Detected Significant Points from a Binary NIfTI File
#'
#' @description
#' Extracts voxel coordinates where \code{pet = 1} (i.e., statistically significant points)
#' from a binary NIfTI file produced by an external SPM analysis.
#' Only voxels from a specific brain slice (\code{z = paramZ}) are retained.
#'
#' The output data frame is structured identically to that of \code{\link{getPoints}},
#' allowing direct comparison between SCC- and SPM-detected regions via \code{\link{calculateMetrics}}.
#'
#' @param niftiFile \code{character}. The path to the binary NIfTI file generated by SPM.
#' @param paramZ \code{integer}. The specific z-slice to extract. Default is \code{35}.
#'
#' @return A data frame with the following columns:
#' \itemize{
#'   \item \code{x}, \code{y} – Coordinates of significant voxels at the specified slice.
#' }
#'
#' @details
#' This function converts externally generated SPM results into a format compatible
#' with SCC analysis tools in \code{neuroSCC}.
#' Use \code{\link{getDimensions}} to inspect the full coordinate space if needed.
#'
#' @examples
#' # Load a sample binary NIfTI file (SPM result)
#' niftiFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
#' detectedSPM <- getSPMbinary(niftiFile, paramZ = 35)
#'
#' # Show detected points
#' head(detectedSPM)
#'
#' @seealso
#' \code{\link{getPoints}} for SCC-based detection. \cr
#' \code{\link{getDimensions}} for obtaining full coordinate grids. \cr
#' \code{\link{calculateMetrics}} for evaluating SCC vs. SPM detection performance.
#'
#' @export
#' @importFrom utils globalVariables
getSPMbinary <- function(niftiFile, paramZ = 35) {

  # 1. Validate Inputs
  # ---------------------------
  if (!file.exists(niftiFile)) stop("NIfTI file not found: ", niftiFile)
  if (!is.numeric(paramZ) || length(paramZ) != 1) stop("'paramZ' must be a single integer.")

  # 2. Load and Process NIfTI File
  # ---------------------------
  voxelData <- neuroCleaner(niftiFile)

  # 3. Filter for Selected Slice and Detected Points
  # ---------------------------
  filteredData <- subset(voxelData, z == paramZ & pet == 1, select = c("x", "y"))

  return(filteredData)
}

#' Generate Synthetic Poisson Clones for PET Data
#'
#' @description
#' Generates synthetic clones of a PET data matrix by adding Poisson-distributed
#' noise to each non-zero voxel. This approach helps address the limitations of functional
#' data analysis (FDA) in single-subject versus group (1 vs. Group) setups, where a single subject
#' lacks sufficient variability to reliably estimate Simultaneous Confidence Corridors (SCCs).
#'
#' @param originalMatrix A numeric matrix where each row represents a flattened PET image.
#' @param numClones An integer specifying the number of synthetic clones to generate.
#' @param lambdaFactor A positive numeric value that scales the magnitude of Poisson noise.
#'
#' @return A numeric matrix with \code{numClones} rows, each representing a noisy version
#'         of \code{originalMatrix} with Poisson noise added.
#'
#' @details
#' \itemize{
#'   \item Values equal to \code{0} remain unchanged to preserve background regions.
#'   \item \code{NA} values are replaced with \code{0} before adding noise.
#'   \item Poisson noise is applied only to positive values, scaled by \code{lambdaFactor}.
#'   \item Enables valid SCC estimation in single-subject settings by artificially increasing sample size.
#' }
#'
#' @examples
#' # Load example input matrix for Poisson cloning
#' data("generatePoissonClonesExample", package = "neuroSCC")
#' # Select 10 random voxel positions for display
#' set.seed(123)
#' sampledCols <- sample(ncol(generatePoissonClonesExample), 10)
#' # Generate 1 synthetic clone
#' clones <- generatePoissonClones(generatePoissonClonesExample, numClones = 1, lambdaFactor = 0.25)
#' # Show voxel intensity values after cloning
#' clones[, sampledCols]
#'
#' @export
#' @importFrom stats rpois
generatePoissonClones <- function(originalMatrix, numClones, lambdaFactor) {

  # 1. Input validation
  # ---------------------------
  if (!is.matrix(originalMatrix)) {
    stop("'originalMatrix' must be a numeric matrix.")
  }
  if (!is.numeric(originalMatrix)) {
    stop("'originalMatrix' must contain only numeric values.")
  }
  if (!is.integer(numClones) && numClones != as.integer(numClones) || numClones <= 0) {
    stop("'numClones' must be a positive integer.")
  }
  if (!is.numeric(lambdaFactor) || lambdaFactor <= 0) {
    stop("'lambdaFactor' must be a positive numeric value.")
  }

  # 2. Prepare output matrix
  # ---------------------------
  numPixels <- ncol(originalMatrix)  # Number of PET pixels (columns)
  cloneMatrix <- matrix(NA, nrow = numClones, ncol = numPixels)  # Preallocate

  # 3. Clone generation
  # ---------------------------
  for (i in seq_len(numClones)) {
    # Apply Poisson noise only to non-zero values
    noise <- ifelse(originalMatrix > 0,
                    rpois(length(originalMatrix), lambda = originalMatrix * lambdaFactor),
                    0)

    # Generate a new synthetic row
    cloneMatrix[i, ] <- originalMatrix + noise
  }

  # 4. Return cloned matrix
  # ---------------------------
  return(cloneMatrix)
}

#' Create a Database of Processed PET Image Data
#'
#' @description
#' Processes multiple PET image files matching a specified filename pattern.
#' Each file is processed using \code{\link{neuroCleaner}}, and the results are aggregated
#' into a unified data frame for functional data analysis. This function serves as a key step
#' in the \code{neuroSCC} workflow, bridging raw image data and Simultaneous Confidence Corridors (SCC) computation.
#'
#' @param pattern \code{character}. A regular expression defining the file pattern to match.
#'        Subject identifiers are extracted from filenames based on this pattern.
#' @param control \code{logical}. If \code{TRUE}, files are treated as control group data;
#'        if \code{FALSE}, as pathological group data. Default is \code{TRUE}.
#' @param useSequentialNumbering \code{logical}. If \code{TRUE}, assigns sequential subject numbers
#'        instead of extracting them from filenames. Default is \code{FALSE}.
#' @param demo \code{data.frame}, optional. If provided, demographic information is included for each file.
#'        Default is \code{NULL}.
#' @param quiet \code{logical}. If \code{TRUE}, suppresses progress messages. Default is \code{FALSE}.
#'
#' @return A \code{data.frame} combining processed voxel-level data from all matched files.
#' Each row represents a voxel (3D pixel). The column structure depends on input
#' \itemize{
#'   \item For the control group: \code{CN_number}, \code{z}, \code{x}, \code{y}, \code{pet}
#'   \item For the pathological group: \code{AD_number}, \code{z}, \code{x}, \code{y}, \code{pet}
#'   \item If demographics are included: additional columns \code{PPT}, \code{Group}, \code{Sex}, \code{Age}
#' }
#'
#' @details
#' The function performs the following steps
#' \enumerate{
#'   \item Identifies image files matching the given pattern.
#'   \item Processes each file using \code{\link{neuroCleaner}}, optionally merging demographic data.
#'   \item Adds a subject identifier column (\code{CN_number} or \code{AD_number}).
#'   \item Aggregates all results into a single data frame.
#' }
#'
#' If no files are successfully processed, an empty data frame is returned with a warning.
#'
#' This function is typically followed by \code{\link{matrixCreator}}, which converts the output
#' into a matrix format for functional analysis.
#'
#' @examples
#' # NOTE: To keep runtime below CRAN limits, this example processes only 1 subject.
#' # You can expand the pattern to include all subjects for real use.
#'
#' # Example: Create a database from a single synthetic PET image (control group)
#' controlPattern <- "^syntheticControl1\\.nii\\.gz$"
#' databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
#' head(databaseControls)
#'
#' @seealso
#' \code{\link{neuroCleaner}} for the underlying image processing function. \cr
#' \code{\link{matrixCreator}} for the next step in the workflow that converts
#' the database to a matrix format for SCC analysis.
#'
#' @export
databaseCreator <- function(pattern, control = TRUE, useSequentialNumbering = FALSE, demo = NULL, quiet = FALSE) {
  # 1. Input validation
  # ---------------------------
  if (!is.character(pattern) || length(pattern) != 1) {
    stop("'pattern' must be a single character string specifying a regular expression")
  }

  if (!is.logical(control) || length(control) != 1) {
    stop("'control' must be a single logical value (TRUE or FALSE)")
  }

  if (!is.logical(useSequentialNumbering) || length(useSequentialNumbering) != 1) {
    stop("'useSequentialNumbering' must be a single logical value (TRUE or FALSE)")
  }

  if (!is.logical(quiet) || length(quiet) != 1) {
    stop("'quiet' must be a single logical value (TRUE or FALSE)")
  }

  if (!is.null(demo) && !is.data.frame(demo)) {
    stop("'demo' must be a data frame or NULL")
  }

  # 2. Get the list of files matching the pattern
  # ---------------------------
  searchPath <- getwd()
  packagePath <- system.file("extdata", package = "neuroSCC")

  if (length(list.files(packagePath, pattern = pattern)) > 0) {
    searchPath <- packagePath
  }

  files <- list.files(path = searchPath, pattern = pattern, full.names = TRUE)

  if (length(files) == 0) {
    stop("Error: No files with this pattern found in: ", searchPath)
  }

  # 3. Initialize storage list for data
  # ---------------------------
  dataList <- list()
  numberLabel <- if (control) "CN_number" else "AD_number"

  # 4. Process each file
  # ---------------------------
  for (i in seq_along(files)) {
    file <- files[i]
    baseName <- basename(file)

    # Extract the number directly from the file name
    number <- sub("^.*?(\\d+)\\.nii\\.gz$", "\\1", baseName)

    if (number == baseName) {
      warning("Could not extract number from: ", baseName, ". Using file index instead.")
      number <- as.character(i)
    }

    # Print progress message if not quiet
    if (!quiet) {
      message("Processing ", numberLabel, " ", number, " - File ", i, " of ", length(files))
    }

    # Process file using neuroCleaner
    tryCatch({
      if (is.null(demo)) {
        tempData <- neuroSCC::neuroCleaner(file)
      } else {
        fileBaseName <- sub("\\.nii\\.gz$", "", baseName)
        demoRow <- demo[demo$PPT == fileBaseName, , drop = FALSE]

        if (nrow(demoRow) == 0) {
          warning("No matching demographic data for ", fileBaseName, ". Using first row instead.")
          demoRow <- demo[1, , drop = FALSE]
        }

        tempData <- neuroSCC::neuroCleaner(file, demo = demoRow)
      }

      # Add subject number to each row
      tempData[[numberLabel]] <- number

      # Store processed data in list
      dataList[[i]] <- tempData

    }, error = function(e) {
      warning("Error processing file: ", baseName, " - ", e$message)
    })
  }

  # 5. Combine all processed data
  # ---------------------------
  if (length(dataList) == 0) {
    warning("No data was successfully processed. Returning empty data frame.")
    return(data.frame())
  }

  database <- do.call(rbind, dataList)

  # 6. Reorder columns
  # ---------------------------
  columnOrder <- c(numberLabel, "PPT", "Group", "Sex", "Age", "z", "x", "y", "pet")
  existingColumns <- intersect(columnOrder, names(database))
  database <- database[, existingColumns]

  return(database)
}

#' Get Dimensions from a Neuroimaging File
#'
#' @description
#' Extracts voxel dimension information from a NIfTI or similar neuroimaging file.
#' This function is designed to work with \code{\link{neuroCleaner}}, but it can also be used
#' independently to inspect image dimensions.
#'
#' @param file A NIfTI file object or a file path pointing to a NIfTI image.
#'
#' @return A named list with the following elements
#' \itemize{
#'   \item \code{xDim} – Number of voxels along the X axis.
#'   \item \code{yDim} – Number of voxels along the Y axis.
#'   \item \code{zDim} – Number of slices along the Z axis.
#'   \item \code{dim} – Total number of voxels in a 2D slice (calculated as \code{xDim * yDim}).
#' }
#'
#' @details
#' The function accepts either a file path or a preloaded \code{nifti} object.
#' If a file path is provided, it uses \code{oro.nifti::readNIfTI()} to load the image.
#' This function ensures consistent dimension extraction across the \code{neuroSCC} pipeline.
#'
#' @examples
#' # Get the file path for a sample NIfTI file
#' niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
#'
#' # Extract dimensions from the NIfTI file
#' dimensions <- getDimensions(niftiFile)
#'
#' # Display the extracted dimensions
#' print(dimensions)
#'
#' @export
getDimensions <- function(file) {
  # Input validation
  if (missing(file)) {
    stop("A NIFTI file or file path must be provided")
  }

  # Handle different input types
  if (is.character(file)) {
    # If a file path is provided, read the NIFTI file
    tryCatch({
      file <- oro.nifti::readNIfTI(fname = file, verbose = FALSE, warn = -1)
    }, error = function(e) {
      stop("Unable to read the NIFTI file: ", e$message)
    })
  }

  # Validate that the input is a NIFTI object
  if (!inherits(file, "nifti")) {
    stop("Input must be a NIFTI file path or a nifti object")
  }

  # Extract dimensions
  xDim <- file@dim_[2]
  yDim <- file@dim_[3]
  zDim <- file@dim_[4]
  dim <- xDim * yDim

  # Return dimensions
  list(
    xDim = xDim,
    yDim = yDim,
    zDim = zDim,
    dim = dim
  )
}

#' Example Input for Poisson Clone Generation
#'
#' @name generatePoissonClonesExample
#' @docType data
#'
#' @description
#' A full single-subject PET matrix used to demonstrate \code{\link{generatePoissonClones}}.
#' This matrix was extracted from simulated neuroimaging data included in the \code{neuroSCC} package.
#'
#' The example avoids long runtime by generating only one synthetic clone.
#'
#' @format A numeric matrix named \code{generatePoissonClonesExample}, with 1 row and all voxel columns.
#'
#' @usage data("generatePoissonClonesExample")
#'
#' @seealso \code{\link{generatePoissonClones}}
#'
#' @source Simulated PET neuroimaging dataset included with \code{neuroSCC}.
#'
#' @keywords datasets
NULL

#' Example SCC object for one-group analysis
#'
#' A single-group Simultaneous Confidence Corridor (SCC) result object
#' used in examples and visualization functions of \pkg{neuroSCC}.
#'
#' The object contains the estimated mean function, SCC bands, spatial
#' coordinates, and triangulation-related components needed for
#' plotting and downstream SCC workflows.
#'
#' @format A list with 14 components, including:
#' \describe{
#'   \item{\code{Yhat}}{Estimated mean function.}
#'   \item{\code{scc}}{Simultaneous confidence corridor bands.}
#'   \item{\code{bw}}{Bandwidth values.}
#'   \item{\code{Ya}}{Observed one-group imaging data.}
#'   \item{\code{V.est.a}}{Triangulation vertices for estimation.}
#'   \item{\code{Tr.est.a}}{Triangulation triangles for estimation.}
#'   \item{\code{Z}}{Spatial coordinates of the imaging domain.}
#'   \item{\code{Z.band}}{Spatial coordinates used for SCC band computation.}
#'   \item{\code{d.est}}{Estimation neighborhood parameter.}
#'   \item{\code{r}}{Radius or smoothing-related SCC parameter.}
#'   \item{\code{ind.inside}}{Indices of points inside the domain.}
#'   \item{\code{ind.inside.cover}}{Indices of covered points inside the domain.}
#'   \item{\code{alpha}}{Significance levels.}
#'   \item{\code{call}}{Call used to generate the SCC object.}
#' }
#'
#' @source Generated from the neuroSCC methodological workflow for one-group SCC analysis.
#'
#' @seealso
#' \code{\link{plotSCCpanel}} for visualization of this object. \cr
#' \code{\link{SCCcomp}} for a two-group SCC example object.
"sccOneGroup"

---
title: "landing_vignette"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{landing_vignette}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup}
library(neuroSCC)
```

# Introduction

This vignette guides you through the initial data preparation steps necessary to use the **neuroSCC** package for analyzing neuroimaging data with Simultaneous Confidence Corridors (SCC).

---

# 1. Loading and Inspecting Neuroimaging Data

We'll begin by loading a sample PET neuroimaging file included with the package and inspecting its structure.

```{r}
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Load and clean data using neuroCleaner
petData <- neuroCleaner(niftiFile)

# Inspect the data
head(petData)
str(petData)
```

---

# 2. Creating a Database from Multiple PET Images

Now, let's demonstrate how to create a structured database using multiple PET files available in the package.

```{r}
# Create database for control subjects
controlPattern <- "^syntheticControl.*\\.nii.gz$"
databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = FALSE)

# Inspect the created database
head(databaseControls)
table(databaseControls$CN_number)
```

---

# 3. Creating the Data Matrix

We'll transform the PET database into a matrix format suitable for SCC analysis.

```{r}
# Create matrix for Z-slice 35
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = FALSE)

# Inspect matrix structure
dim(matrixControls)
str(matrixControls)
```

---

# 4. Normalizing the Data Matrix

Normalization adjusts for global intensity differences between subjects.

```{r}
# Perform mean normalization
normalizedMatrix <- meanNormalization(matrixControls, returnDetails = FALSE)

```

---

# 5. Extracting Contours for Triangulation

Contours from the neuroimage are used to set boundaries for SCC computations.

```{r, fig.alt="Contours for brain imaging data"}
# Extract contours from sample data
contours <- neuroContour(niftiFile, paramZ = 35, plotResult = TRUE)

# Check contours structure
length(contours)
str(contours[[1]])
```

---

# 6. Conditional Triangulation Setup (optional)

The triangulation step requires the external `Triangulation` package, currently not on CRAN. Ensure you have this package installed. If not, install it using:

```r
remotes::install_github("FIRST-Data-Lab/Triangulation")
```

Conditional example for triangulation:

```{r, fig.alt="Delaunay triangulations for brain imaging data", eval = requireNamespace("ImageSCC", quietly = TRUE)}

if (!requireNamespace("Triangulation", quietly = TRUE)) {
  cat("Triangulation package is not installed.\nInstall it using: remotes::install_github('FIRST-Data-Lab/Triangulation')\n")
} else {
  # Perform triangulation with the first contour
  mesh <- Triangulation::TriMesh(n = 15, contours[[1]])
  
  # Inspect mesh
  print(mesh[["V"]][1:10, ])
  print(mesh[["Tr"]][1:10, ])
}

```

---

# What's Next?

You're now ready to perform Simultaneous Confidence Corridor analyses:

- Single-group SCC analysis (see `one_group_scc` vignette)
- Two-group comparison SCC (see `two_group_comparison` vignette)
- Single patient vs. group analysis (see `one_vs_group` vignette)

Feel free to explore these vignettes to continue your analysis journey with neuroSCC.

---
title: "two_group_comparison"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{two_group_comparison}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r eval=TRUE, echo=FALSE}
library(neuroSCC)
```

# Introduction

This vignette demonstrates a minimal example of performing a **group vs. group** SCC analysis using the `neuroSCC` package.

It is recommended that you first complete the ["Getting Started"](landing_vignette.html) vignette. If you haven't, the following section will guide you through the necessary data preparation.

---

# Data Preparation (Conditional)

First, let's conditionally prepare the required data (control and pathological matrices). We use sample data included in the package.

```{r}

# Recreate necessary data from sample files
cat("Creating sample data for 2-group comparison...\n")

# Create databases for Control and Pathological groups
databaseControls <- databaseCreator(pattern = "^syntheticControl[12]\\.nii\\.gz$", control = TRUE, quiet = TRUE)
databasePathological <- databaseCreator(pattern = "^syntheticPathological[12]\\.nii\\.gz$", control = FALSE, quiet = TRUE)

# Create matrices suitable for SCC
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)
matrixPathological <- matrixCreator(databasePathological, paramZ = 35, quiet = TRUE)

# Normalize matrices
normalizedControls <- meanNormalization(matrixControls)
normalizedPathological <- meanNormalization(matrixPathological)

# Extract contours from a control subject for SCC triangulation
niftiPath <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")
contours <- neuroContour(niftiPath, paramZ = 35, plotResult = FALSE)

cat("Data preparation completed successfully.\n")

```

---

# SCC Estimation (Group vs Group)

This step requires the external `ImageSCC` package, currently not on CRAN. Ensure you have this package installed. If not, install it using:

```{r}

if (requireNamespace("ImageSCC", quietly = TRUE)) {
  message("'ImageSCC' package is available.")
} else {
  message("This vignette requires the 'ImageSCC' package.")
  message("You can install it from GitHub with:")
  message("  remotes::install_github('FIRST-Data-Lab/ImageSCC')")
}

```

The SCC estimation step is computationally intensive and thus typically skipped in vignette demonstrations. Below, we conditionally load a precomputed SCC result provided with the package.


```{r eval = requireNamespace("ImageSCC", quietly = TRUE), echo=TRUE}

# Check for Triangulation package
triangulation_available <- requireNamespace("Triangulation", quietly = TRUE)

if (triangulation_available) {
  message("'Triangulation' package is available.")
} else {
  message("'Triangulation' package not available.")
  message("Install with: remotes::install_github('FIRST-Data-Lab/Triangulation')")
}

# Proceed only if both packages are available
if (triangulation_available) {

  # Try loading precomputed SCC object from data/
  if (!exists("SCCcomp", inherits = FALSE) &&
      "SCCcomp" %in% data(package = "neuroSCC")$results[, "Item"]) {
    
    message("Loading precomputed SCC group comparison from package data...")
    suppressMessages(data("SCCcomp", package = "neuroSCC"))

  } else if (!exists("SCCcomp", inherits = FALSE)) {

    message("Precomputed data not found. Running SCC estimation...")

    # Perform SCC computation (only for development)
    SCCcomp <- ImageSCC::scc.image(
      Ya = normalizedPathological,
      Yb = normalizedControls,
      Z = contours[[1]],
      d.est = 5,
      d.band = 2,
      r = 1,
      V.est.a = as.matrix(contours[[1]]),
      Tr.est.a = as.matrix(contours[[1]]),
      V.band.a = as.matrix(contours[[1]]),
      Tr.band.a = as.matrix(contours[[1]]),
      penalty = TRUE,
      lambda = 10^{seq(-6, 3, 0.5)},
      alpha.grid = c(0.10, 0.05, 0.01),
      adjust.sigma = TRUE
    )
  }
}


```

```{r eval=TRUE}
if (!exists("SCCcomp", inherits = FALSE)) {
  data("SCCcomp", package = "neuroSCC")
}
```

---

# Visualizing Group Means and SCC Differences

Once the SCC result is available, it is often useful to visualize both group mean estimates together with the SCC-detected differences. The panel below provides a compact summary of the two-group comparison.

```{r eval=TRUE, fig.alt="Two-group SCC comparison panel"}
plotSCCcomparisonPanel(
  scc = SCCcomp,
  title = "SCC COMPARISON PANEL"
)
```

---

# Extracting Significant Points and Evaluating Metrics

With the SCC results (`SCCcomp`) loaded, we extract the significant regions and evaluate their performance against known ground truth ROIs.

```{r eval=TRUE}
# Extract significant points from SCC results
significantPoints <- getPoints(SCCcomp)

# Load true ROI data provided within the package
roi_path <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
trueROI <- processROIs(roi_path, region = "Region2", number = "18", save = FALSE)

# Get total coordinate dimensions
dimensions <- getDimensions(roi_path)
totalCoords <- expand.grid(x = 1:dimensions$xDim, y = 1:dimensions$yDim)

# Calculate metrics to evaluate detection performance
metrics <- calculateMetrics(
  detectedPoints = significantPoints$positivePoints,
  truePoints = trueROI,
  totalCoords = dimensions,
  regionName = "Group_vs_Group"
)

# Display calculated metrics
print(metrics)
```

---

# Visual Validation Against ROI and SPM

In addition to numerical metrics, it can be useful to visually compare the ground-truth ROI, SCC detections, and SPM detections over the same anatomical background. The following panel provides that comparison.

```{r eval=TRUE, fig.alt="Validation panel comparing ROI, SCC, and SPM detections"}
paramZ <- 35

controlPattern <- "^syntheticControl.*\\.nii\\.gz$"
databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
matrixCN <- meanNormalization(matrixCN)

roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))

spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)

plotValidationPanel(
  template = roiFile,
  backgroundMatrix = matrixCN,
  roiPoints = roiPoints,
  sccPoints = list(
    positivePoints = getPoints(SCCcomp)$positivePoints,
    negativePoints = data.frame(x = numeric(0), y = numeric(0))
  ),
  spmPoints = spmPoints,
  title = "Performance Validation Panel",
  label1 = "Ground Truth (ROI)",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)
```

---

# Conclusion

In this vignette, you've seen a concise example of conducting a **group vs group SCC analysis** using the `neuroSCC` package. We've used sample data provided by the package to illustrate the workflow clearly, focusing on practical application and evaluation of results. 

Actual SCC computations are computationally intensive and thus skipped in this vignette. Instead, we've loaded precomputed results. You can adapt this template for your own datasets, adjusting parameters and experimenting further according to your specific research needs.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getDimensions.R
\name{getDimensions}
\alias{getDimensions}
\title{Get Dimensions from a Neuroimaging File}
\usage{
getDimensions(file)
}
\arguments{
\item{file}{A NIfTI file object or a file path pointing to a NIfTI image.}
}
\value{
A named list with the following elements
\itemize{
  \item \code{xDim} – Number of voxels along the X axis.
  \item \code{yDim} – Number of voxels along the Y axis.
  \item \code{zDim} – Number of slices along the Z axis.
  \item \code{dim} – Total number of voxels in a 2D slice (calculated as \code{xDim * yDim}).
}
}
\description{
Extracts voxel dimension information from a NIfTI or similar neuroimaging file.
This function is designed to work with \code{\link{neuroCleaner}}, but it can also be used
independently to inspect image dimensions.
}
\details{
The function accepts either a file path or a preloaded \code{nifti} object.
If a file path is provided, it uses \code{oro.nifti::readNIfTI()} to load the image.
This function ensures consistent dimension extraction across the \code{neuroSCC} pipeline.
}
\examples{
# Get the file path for a sample NIfTI file
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Extract dimensions from the NIfTI file
dimensions <- getDimensions(niftiFile)

# Display the extracted dimensions
print(dimensions)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotValidationPanel.R
\name{plotValidationPanel}
\alias{plotValidationPanel}
\title{Plot ROI, SCC detections, and SPM detections for validation}
\usage{
plotValidationPanel(
  template,
  backgroundMatrix,
  roiPoints,
  sccPoints,
  spmPoints,
  title = "COMPARISON PANEL",
  label1 = "True ROI",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)
}
\arguments{
\item{template}{\code{character}, path to a NIfTI file used to obtain the
grid dimensions of the imaging domain.}

\item{backgroundMatrix}{A numeric matrix used to generate the grayscale
background image.}

\item{roiPoints}{A \code{data.frame} with columns \code{x} and \code{y}
containing the ground-truth ROI points.}

\item{sccPoints}{A list containing \code{positivePoints} and
\code{negativePoints}, each as a \code{data.frame} with columns
\code{x} and \code{y}.}

\item{spmPoints}{A \code{data.frame} with columns \code{x} and \code{y}
containing the SPM-detected points.}

\item{title}{\code{character}, title shown above the panel.}

\item{label1}{\code{character}, title of the ground-truth ROI panel.}

\item{label2}{\code{character}, title of the SCC-detected panel.}

\item{label3}{\code{character}, title of the SPM-detected panel.}
}
\value{
A patchwork/ggplot object containing three aligned panels:
\itemize{
  \item ground-truth ROI,
  \item SCC-detected points,
  \item SPM-detected points.
}
}
\description{
This function visualizes the ground-truth ROI, SCC-detected points,
and SPM-detected points as a three-panel comparison over a shared
neuroimaging background.
}
\details{
The three panels share the same grayscale background to facilitate visual
comparison between the true ROI and the points detected by SCC and SPM.

In the examples, SCC detections are restricted to positive points only
to keep the visualization simple. With real analysis outputs,
\code{sccPoints} would typically be supplied directly as
\code{getPoints(<SCC object>)}.
}
\examples{
\donttest{
paramZ <- 35

controlPattern <- "^syntheticControl.*\\\\.nii\\\\.gz$"
databaseCN <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
matrixCN <- matrixCreator(database = databaseCN, paramZ = paramZ, quiet = TRUE)
matrixCN <- meanNormalization(matrixCN)

roiFile <- system.file("extdata", "ROIsample_Region2_18.nii.gz", package = "neuroSCC")
truePoints <- processROIs(roiFile, region = "Region2", number = "18", save = FALSE)
roiPoints <- subset(truePoints, z == paramZ & pet == 1, select = c("x", "y"))

spmFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
spmPoints <- getSPMbinary(spmFile, paramZ = paramZ)

data("SCCcomp", package = "neuroSCC")

plotValidationPanel(
  template = roiFile,
  backgroundMatrix = matrixCN,
  roiPoints = roiPoints,
  sccPoints = list(
    positivePoints = getPoints(SCCcomp)$positivePoints,
    negativePoints = data.frame(x = numeric(0), y = numeric(0))
  ),
  spmPoints = spmPoints,
  title = "Performance Validation Panel",
  label1 = "Ground Truth (ROI)",
  label2 = "SCC Detected",
  label3 = "SPM Detected"
)
}

}
\seealso{
\code{\link{SCCcomp}} for the example SCC object used in the examples. \cr
\code{\link{getPoints}} for extraction of SCC-detected significant points. \cr
\code{\link{getSPMbinary}} for extraction of SPM-detected significant points. \cr
\code{\link{processROIs}} for extraction of ground-truth ROI points.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateMetricsExample.R
\docType{data}
\name{calculateMetricsExample}
\alias{calculateMetricsExample}
\title{Precomputed Inputs for SCC vs. SPM Performance Evaluation}
\format{
A set of four objects:
\describe{
  \item{\code{detectedSCC}}{Data frame of SCC-detected coordinates (from \code{\link{getPoints}}).}
  \item{\code{detectedSPM}}{Data frame of SPM-detected coordinates (from \code{\link{getSPMbinary}}).}
  \item{\code{trueROI}}{Ground truth ROI voxel data (from \code{\link{processROIs}}).}
  \item{\code{totalCoords}}{List with full image grid dimensions (from \code{\link{getDimensions}}).}
}
}
\source{
Simulated PET neuroimaging study for testing SCC and SPM detection accuracy.
}
\usage{
data("calculateMetricsExample")
}
\description{
A dataset containing all necessary inputs for demonstrating \code{\link{calculateMetrics}}.
It enables reproducible and fast example code that compares SCC-detected and SPM-detected
points against a known ground truth ROI.

These inputs were generated using sample PET and ROI files included in the \code{neuroSCC} package.
}
\seealso{
\code{\link{calculateMetrics}}, \code{\link{getPoints}}, \code{\link{getSPMbinary}},
         \code{\link{processROIs}}, \code{\link{getDimensions}}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SCCcomp.R
\docType{data}
\name{SCCcomp}
\alias{SCCcomp}
\title{Example SCC Computation Result}
\format{
A named list of class \code{"image"} with the following elements
\describe{
  \item{\code{scc}}{3D array of SCC confidence bands, dimensions \code{[n, 2, alpha]}.}
  \item{\code{Z.band}}{Matrix of grid coordinates corresponding to evaluated locations.}
  \item{\code{ind.inside.cover}}{Integer vector of indices for grid points inside the SCC band.}
  \item{\code{V.est.a}, \code{V.est.b}}{Vertex matrices for triangulated domains (pathological and control groups).}
  \item{\code{Tr.est.a}, \code{Tr.est.b}}{Triangle index matrices corresponding to the domain meshes.}
  \item{\code{alpha}}{Vector of confidence levels used (e.g., 0.1, 0.05, 0.01).}
  \item{\code{d.est}}{Spline degree used in mean function estimation.}
  \item{\code{r}}{Smoothing parameter used during fitting.}
}
}
\source{
Simulated PET neuroimaging study for evaluating SCC methodology.
}
\usage{
data("SCCcomp")
}
\description{
A precomputed example of a Simultaneous Confidence Corridor (SCC) analysis
comparing a group of pathological subjects against controls. This object was generated
using the \code{ImageSCC::scc.image} function and represents a realistic output
from SCC-based neuroimaging group comparisons.

This dataset is used in the examples of \code{\link{getPoints}} and \code{\link{calculateMetrics}},
allowing users to explore SCC outputs without needing to recompute them.
}
\seealso{
\code{\link{getPoints}}, \code{\link{calculateMetrics}}, \code{ImageSCC::scc.image}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sccOneGroup.R
\docType{data}
\name{sccOneGroup}
\alias{sccOneGroup}
\title{Example SCC object for one-group analysis}
\format{
A list with 14 components, including:
\describe{
  \item{\code{Yhat}}{Estimated mean function.}
  \item{\code{scc}}{Simultaneous confidence corridor bands.}
  \item{\code{bw}}{Bandwidth values.}
  \item{\code{Ya}}{Observed one-group imaging data.}
  \item{\code{V.est.a}}{Triangulation vertices for estimation.}
  \item{\code{Tr.est.a}}{Triangulation triangles for estimation.}
  \item{\code{Z}}{Spatial coordinates of the imaging domain.}
  \item{\code{Z.band}}{Spatial coordinates used for SCC band computation.}
  \item{\code{d.est}}{Estimation neighborhood parameter.}
  \item{\code{r}}{Radius or smoothing-related SCC parameter.}
  \item{\code{ind.inside}}{Indices of points inside the domain.}
  \item{\code{ind.inside.cover}}{Indices of covered points inside the domain.}
  \item{\code{alpha}}{Significance levels.}
  \item{\code{call}}{Call used to generate the SCC object.}
}
}
\source{
Generated from the neuroSCC methodological workflow for one-group SCC analysis.
}
\usage{
sccOneGroup
}
\description{
A single-group Simultaneous Confidence Corridor (SCC) result object
used in examples and visualization functions of \pkg{neuroSCC}.
}
\details{
The object contains the estimated mean function, SCC bands, spatial
coordinates, and triangulation-related components needed for
plotting and downstream SCC workflows.
}
\seealso{
\code{\link{plotSCCpanel}} for visualization of this object. \cr
\code{\link{SCCcomp}} for a two-group SCC example object.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generatePoissonClonesExample.R
\docType{data}
\name{generatePoissonClonesExample}
\alias{generatePoissonClonesExample}
\title{Example Input for Poisson Clone Generation}
\format{
A numeric matrix named \code{generatePoissonClonesExample}, with 1 row and all voxel columns.
}
\source{
Simulated PET neuroimaging dataset included with \code{neuroSCC}.
}
\usage{
data("generatePoissonClonesExample")
}
\description{
A full single-subject PET matrix used to demonstrate \code{\link{generatePoissonClones}}.
This matrix was extracted from simulated neuroimaging data included in the \code{neuroSCC} package.

The example avoids long runtime by generating only one synthetic clone.
}
\seealso{
\code{\link{generatePoissonClones}}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/neuroSCC-package.R
\docType{package}
\name{neuroSCC-package}
\alias{neuroSCC-package}
\alias{neuroSCC}
\title{Wrappers for Neuroimaging Functional Data Preparation and SCC Analysis}
\description{
The \code{neuroSCC} package provides tools to preprocess and structure neuroimaging data
for functional data analysis using Simultaneous Confidence Corridors (SCCs). It wraps external packages
to prepare data from PET images, extract contours, generate meshes, and evaluate regions of statistical significance.

The methods implemented support both group comparisons and single-subject vs. group inference,
following the methodology described in Wang et al. (2020) and the author's PhD thesis.
}
\details{
This package serves as a bridge between neuroimaging file formats (e.g., NIfTI) and advanced
statistical tools like \code{ImageSCC::scc.image}. It includes the following key components.
\itemize{
  \item Loading and cleaning PET image data.
  \item Extracting ROIs and constructing functional data matrices.
  \item Generating synthetic Poisson clones for 1-vs-group settings.
  \item Extracting SCC-detected points and evaluating detection metrics.
}
}
\seealso{
\code{\link{neuroCleaner}}, \code{\link{databaseCreator}}, \code{\link{getPoints}}
}
\author{
\strong{Maintainer}: Juan A. Arias Lopez \email{iguanamarina@protonmail.com} (\href{https://orcid.org/0000-0002-3355-6393}{ORCID}) [copyright holder]

Other contributors:
\itemize{
  \item Virgilio Gomez Rubio \email{Virgilio.Gomez@uclm.es} (\href{https://orcid.org/0000-0002-4791-3072}{ORCID}) [reviewer]
  \item Pablo Aguiar Fernandez \email{pablo.aguiar@usc.es} (\href{https://orcid.org/0000-0002-7322-2195}{ORCID}) [thesis advisor]
  \item Andrew Haddon Kemp \email{A.H.Kemp@swansea.ac.uk} (\href{https://orcid.org/0000-0003-1146-3791}{ORCID}) [thesis advisor]
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getPoints.R
\name{getPoints}
\alias{getPoints}
\title{Extract Significant SCC Points from an SCC Comparison Object}
\usage{
getPoints(sccResult)
}
\arguments{
\item{sccResult}{A list of SCC computation results, as returned by \code{ImageSCC::scc.image}.
Must include the following components
\itemize{
  \item \code{Z.band} — A matrix specifying grid positions.
  \item \code{ind.inside.cover} — Indices of grid points within the confidence band.
  \item \code{scc} — A 3D array containing the computed SCC values.
}}
}
\value{
A named list with two elements
\itemize{
  \item \code{positivePoints} — A data frame with coordinates where the \strong{first group (Ya)} shows
        significantly lower activity than the \strong{second group (Yb)}.
  \item \code{negativePoints} — A data frame with coordinates where the \strong{first group (Ya)} shows
        significantly higher activity than the \strong{second group (Yb)}.
}
}
\description{
Identifies and extracts coordinates where differences fall outside the simultaneous confidence corridors (SCCs),
indicating statistically significant regions. This function processes the results from
\code{ImageSCC::scc.image()} and returns the voxel locations that represent either hypo- or hyperactivity.

Interpretation depends on the order of inputs in the SCC computation.
If SCC was computed as \code{scc.image(Ya = Y_AD, Yb = Y_CN, ...)} (i.e., the Control group is the second argument).

\itemize{
  \item \code{positivePoints} — Regions where Control minus Pathological is significantly above the SCC.
    These correspond to areas where the Pathological group (AD) is \emph{hypoactive} relative to Controls.
  \item \code{negativePoints} — Regions where Control minus Pathological is significantly below the SCC.
    These correspond to areas where the Pathological group is \emph{hyperactive} relative to Controls.
}

\strong{Always confirm the order of \code{Ya} and \code{Yb} in the SCC computation}
to interpret the directionality correctly.
}
\examples{
# Load precomputed SCC example
data("SCCcomp", package = "neuroSCC")

# Extract significant SCC points
significantPoints <- getPoints(SCCcomp)

# Show extracted points (interpretation depends on SCC setup; see description)
head(significantPoints$positivePoints)  # Pathological hypoactive vs. Control
head(significantPoints$negativePoints)  # Pathological hyperactive vs. Control

}
\seealso{
\code{ImageSCC::scc.image} for SCC computation.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotSCCcomparisonPanel.R
\name{plotSCCcomparisonPanel}
\alias{plotSCCcomparisonPanel}
\title{Plot group means and SCC comparison overlay}
\usage{
plotSCCcomparisonPanel(
  scc,
  title = NULL,
  zlim = "auto",
  palette = "nih",
  label1 = "Group 1 Mean",
  label2 = "Group 2 Mean",
  label3 = "SCC Overlay",
  overlay = c("positive", "negative", "both", "none"),
  useRawMeans = FALSE
)
}
\arguments{
\item{scc}{A list-like SCC result object, typically returned by
\code{ImageSCC::scc.image()}, containing the components required for
plotting group means and SCC-derived significant points.}

\item{title}{\code{character}, title shown above the panel. If \code{NULL},
the default title is \code{"SCC COMPARISON PANEL"}.}

\item{zlim}{Either \code{"auto"} to compute color limits from the plotted values,
or a numeric vector of length 2 specifying the lower and upper limits of the
fill scale.}

\item{palette}{\code{character}, color palette used in the mean heatmaps.
Supported values are \code{"nih"}, \code{"viridis"}, and \code{"gray"}.}

\item{label1}{\code{character}, title of the first group panel.}

\item{label2}{\code{character}, title of the second group panel.}

\item{label3}{\code{character}, title of the SCC overlay panel.}

\item{overlay}{\code{character}, which SCC-detected points to overlay in the
third panel. Supported values are \code{"positive"}, \code{"negative"},
\code{"both"}, and \code{"none"}.}

\item{useRawMeans}{\code{logical}, if \code{TRUE}, the group means are computed
directly from \code{scc$Ya} and \code{scc$Yb}. If \code{FALSE}, the function
uses \code{scc$Yhat}.}
}
\value{
A patchwork/ggplot object containing three aligned panels:
\itemize{
  \item mean estimate for group 1,
  \item mean estimate for group 2,
  \item SCC overlay panel with detected positive and/or negative points.
}
}
\description{
This function visualizes a two-group Simultaneous Confidence Corridor (SCC)
result as a three-panel figure showing the mean estimate for each group and
an overlay panel with SCC-detected differences.
}
\details{
The first two panels use a shared continuous color scale to facilitate direct
comparison between group mean estimates. The third panel uses a grayscale
background and overlays SCC-detected significant points.

Positive and negative SCC detections are obtained internally using
\code{\link{getPoints}}.
}
\examples{
data("SCCcomp", package = "neuroSCC")
plotSCCcomparisonPanel(SCCcomp, title = "SCC COMPARISON PANEL")

}
\seealso{
\code{\link{SCCcomp}} for the example two-group SCC object used in the examples. \cr
\code{\link{getPoints}} for extraction of SCC-detected significant points. \cr
\code{\link{plotSCCpanel}} for single-group SCC visualization. \cr
\code{\link{plotValidationPanel}} for SCC versus SPM performance visualization.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/neuroCleaner.R
\name{neuroCleaner}
\alias{neuroCleaner}
\title{Clean and Load Data from NIfTI Neuroimaging Files}
\usage{
neuroCleaner(name, demo = NULL, demoRow = 1)
}
\arguments{
\item{name}{\code{character}. The full path to the NIfTI file to process.}

\item{demo}{Optional \code{data.frame} containing demographic information.
If provided, it should include columns (case-insensitive): \code{PPT}, \code{Group}, \code{Sex}, and \code{Age}.
If automatic matching via the \code{PPT} column fails, the row specified by \code{demoRow} is used. Default is \code{NULL}.}

\item{demoRow}{\code{integer}. Row to use from the demographic table if automatic matching fails. Default is \code{1}.}
}
\value{
A data frame where each row represents a voxel (3D pixel).
\itemize{
  \item If demographics are provided: the columns include \code{PPT}, \code{Group}, \code{Sex}, \code{Age}, \code{z}, \code{x}, \code{y}, and \code{pet}.
  \item If demographics are not provided: the columns include \code{z}, \code{x}, \code{y}, and \code{pet}.
}
The \code{pet} column contains the PET intensity value at each voxel location.
}
\description{
Loads a NIfTI-format neuroimaging file and transforms it into a structured data frame,
organizing voxel-level information for downstream analysis. This function is the first step
in the neuroimaging processing pipeline in \code{neuroSCC}, converting raw PET data into
a format suitable for functional data analysis. SCCs are later computed using functions
from the \code{ImageSCC} package, such as \code{ImageSCC::scc.image()}.
}
\details{
The function performs the following steps
\enumerate{
  \item Loads the NIfTI file using \code{oro.nifti::readNIfTI()}.
  \item Converts the 3D image into a tidy data frame.
  \item Adds \code{z}, \code{x}, and \code{y} voxel coordinates.
  \item If demographic data is provided, attempts to match based on \code{PPT} (case-insensitive). If no match is found, \code{demoRow} is used.
}

The resulting data frame serves as input for \code{\link{databaseCreator}}, \code{\link{matrixCreator}},
and other core functions in the \code{neuroSCC} pipeline.
}
\examples{
# Load a sample Control NIfTI file
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Example Without demographic data
petData <- neuroCleaner(niftiFile)
petData[sample(nrow(petData), 10), ]  # Show 10 random voxels

}
\seealso{
\code{\link{databaseCreator}} for batch image processing. \cr
\code{\link[oro.nifti]{readNIfTI}} for reading NIfTI-format files.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getSPMbinary.R
\name{getSPMbinary}
\alias{getSPMbinary}
\title{Extract SPM-Detected Significant Points from a Binary NIfTI File}
\usage{
getSPMbinary(niftiFile, paramZ = 35)
}
\arguments{
\item{niftiFile}{\code{character}. The path to the binary NIfTI file generated by SPM.}

\item{paramZ}{\code{integer}. The specific z-slice to extract. Default is \code{35}.}
}
\value{
A data frame with the following columns:
\itemize{
  \item \code{x}, \code{y} – Coordinates of significant voxels at the specified slice.
}
}
\description{
Extracts voxel coordinates where \code{pet = 1} (i.e., statistically significant points)
from a binary NIfTI file produced by an external SPM analysis.
Only voxels from a specific brain slice (\code{z = paramZ}) are retained.

The output data frame is structured identically to that of \code{\link{getPoints}},
allowing direct comparison between SCC- and SPM-detected regions via \code{\link{calculateMetrics}}.
}
\details{
This function converts externally generated SPM results into a format compatible
with SCC analysis tools in \code{neuroSCC}.
Use \code{\link{getDimensions}} to inspect the full coordinate space if needed.
}
\examples{
# Load a sample binary NIfTI file (SPM result)
niftiFile <- system.file("extdata", "binary.nii.gz", package = "neuroSCC")
detectedSPM <- getSPMbinary(niftiFile, paramZ = 35)

# Show detected points
head(detectedSPM)

}
\seealso{
\code{\link{getPoints}} for SCC-based detection. \cr
\code{\link{getDimensions}} for obtaining full coordinate grids. \cr
\code{\link{calculateMetrics}} for evaluating SCC vs. SPM detection performance.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/neuroContour.R
\name{neuroContour}
\alias{neuroContour}
\title{Obtain neuroimaging contours from a NIFTI file}
\usage{
neuroContour(niftiFile, paramZ = 35, plotResult = FALSE)
}
\arguments{
\item{niftiFile}{\code{character}, the path to the NIFTI file containing neuroimaging data.
Ideally, the file should be masked so that zero values represent the background.}

\item{paramZ}{\code{integer}, the specific z-slice to extract contours from. Default is \code{35}.}

\item{plotResult}{\code{logical}, if \code{TRUE}, plots the extracted contours. Default is \code{FALSE}.}
}
\value{
A \code{list} of data frames, where each data frame contains the x and y coordinates of a contour.
The first element typically represents the external boundary, while subsequent elements (if present)
represent internal contours or holes. Each data frame has two columns:
\itemize{
  \item \code{x} - x-coordinates of the contour points.
  \item \code{y} - y-coordinates of the contour points.
}
}
\description{
This function extracts contours from a neuroimaging NIFTI file by identifying
the boundary of the non-zero image support in a selected z-slice.
These contours serve as input for \code{Triangulation::TriMesh},
which is used in Simultaneous Confidence Corridors (SCCs) calculations.

It is highly recommended that the input NIFTI file be pre-processed such that
zero values represent the background and non-zero values represent regions of interest.
}
\details{
This function extracts contours from a \strong{NIFTI} file, typically a masked image where
background values are zero and regions of interest contain non-zero values.
Contours are computed from the boundary of the non-zero support of the selected slice.

The extracted contours are typically used as input to \code{Triangulation::TriMesh}
to create a triangular mesh of the region, which is then used for
Simultaneous Confidence Corridors calculations.
}
\examples{
# Get the file path for a sample NIfTI file
niftiFile <- system.file("extdata", "syntheticControl1.nii.gz", package = "neuroSCC")

# Extract contours from the non-zero support
contours <- neuroContour(niftiFile, paramZ = 35, plotResult = TRUE)

# Display the first few points of the main contour
head(contours[[1]])

}
\seealso{
\code{Triangulation::TriMesh} for the next step in the SCC calculation process.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateMetrics.R
\name{calculateMetrics}
\alias{calculateMetrics}
\title{Evaluate SCC or SPM Detection Performance}
\usage{
calculateMetrics(detectedPoints, truePoints, totalCoords, regionName)
}
\arguments{
\item{detectedPoints}{A data frame containing detected coordinates (\code{x}, \code{y}).
SCC-detected points should be obtained using \code{\link{getPoints}}.
SPM-detected points should be obtained using \code{\link{getSPMbinary}}.}

\item{truePoints}{A data frame with ground truth ROI coordinates (\code{x}, \code{y}),
extracted via \code{\link{processROIs}}.}

\item{totalCoords}{A list with the full voxel grid dimensions, created by \code{\link{getDimensions}}.
Must include named elements \code{xDim} and \code{yDim}.}

\item{regionName}{A character string used to label the output region.}
}
\value{
A data frame with the following evaluation metrics
\itemize{
  \item \code{region}: Name of the analyzed region.
  \item \code{sensitivity}: True positive rate (TP / (TP + FN) * 100).
  \item \code{specificity}: True negative rate (TN / (TN + FP) * 100).
  \item \code{PPV}: Positive predictive value (TP / (TP + FP) * 100).
  \item \code{NPV}: Negative predictive value (TN / (TN + FN) * 100).
}
}
\description{
Computes Sensitivity, Specificity, Positive Predictive Value (PPV), and Negative Predictive Value (NPV)
by comparing detected points with ground truth ROI points. This function is used to assess
the accuracy of SCC- or SPM-based detection in neuroimaging analysis.
}
\details{
This function requires three precomputed objects
\itemize{
  \item \code{detectedPoints}: SCC-detected points from \code{\link{getPoints}} or SPM-detected points from \code{\link{getSPMbinary}}.
  \item \code{truePoints}: Ground truth ROIs extracted using \code{\link{processROIs}}.
  \item \code{totalCoords}: Full voxel coordinate grid from \code{\link{getDimensions}}.
}
}
\examples{
# Load precomputed inputs for the example
data("calculateMetricsExample", package = "neuroSCC")

# Evaluate SCC and SPM detection performance
with(calculateMetricsExample, {
  metricsSCC <- calculateMetrics(detectedSCC, trueROI, totalCoords, "Region2_SCC")
  metricsSPM <- calculateMetrics(detectedSPM, trueROI, totalCoords, "Region2_SPM")

  print(metricsSCC)
  print(metricsSPM)
})

}
\seealso{
\code{\link{getPoints}} for SCC-detected regions. \cr
\code{\link{getSPMbinary}} for binary SPM-detected points. \cr
\code{\link{processROIs}} for defining ground truth ROIs. \cr
\code{\link{getDimensions}} for generating the coordinate grid.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generatePoissonClones.R
\name{generatePoissonClones}
\alias{generatePoissonClones}
\title{Generate Synthetic Poisson Clones for PET Data}
\usage{
generatePoissonClones(originalMatrix, numClones, lambdaFactor)
}
\arguments{
\item{originalMatrix}{A numeric matrix where each row represents a flattened PET image.}

\item{numClones}{An integer specifying the number of synthetic clones to generate.}

\item{lambdaFactor}{A positive numeric value that scales the magnitude of Poisson noise.}
}
\value{
A numeric matrix with \code{numClones} rows, each representing a noisy version
        of \code{originalMatrix} with Poisson noise added.
}
\description{
Generates synthetic clones of a PET data matrix by adding Poisson-distributed
noise to each non-zero voxel. This approach helps address the limitations of functional
data analysis (FDA) in single-subject versus group (1 vs. Group) setups, where a single subject
lacks sufficient variability to reliably estimate Simultaneous Confidence Corridors (SCCs).
}
\details{
\itemize{
  \item Values equal to \code{0} remain unchanged to preserve background regions.
  \item \code{NA} values are replaced with \code{0} before adding noise.
  \item Poisson noise is applied only to positive values, scaled by \code{lambdaFactor}.
  \item Enables valid SCC estimation in single-subject settings by artificially increasing sample size.
}
}
\examples{
# Load example input matrix for Poisson cloning
data("generatePoissonClonesExample", package = "neuroSCC")
# Select 10 random voxel positions for display
set.seed(123)
sampledCols <- sample(ncol(generatePoissonClonesExample), 10)
# Generate 1 synthetic clone
clones <- generatePoissonClones(generatePoissonClonesExample, numClones = 1, lambdaFactor = 0.25)
# Show voxel intensity values after cloning
clones[, sampledCols]

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/matrixCreator.R
\name{matrixCreator}
\alias{matrixCreator}
\title{Convert Database to Functional Data Matrix Format}
\usage{
matrixCreator(
  database,
  paramZ = 35,
  useSequentialNumbering = FALSE,
  quiet = FALSE
)
}
\arguments{
\item{database}{A data frame created by \code{\link{databaseCreator}}, containing
voxel-level PET image data, including subject identifiers, coordinates, and intensity values.}

\item{paramZ}{An integer specifying the z-coordinate (slice) to extract. Default is \code{35}.}

\item{useSequentialNumbering}{\code{logical}. If \code{TRUE}, assigns sequential subject IDs
instead of extracting them from filenames. Not currently used inside this function. Default is \code{FALSE}.}

\item{quiet}{\code{logical}. If \code{TRUE}, suppresses progress messages. Default is \code{FALSE}.}
}
\value{
A numeric matrix where
\itemize{
  \item Each row represents one subject's PET values at the selected z-slice.
  \item Each column corresponds to a voxel (flattened as a 1D row).
}
}
\description{
Converts a PET image database (created via \code{\link{databaseCreator}}) into
a matrix format suitable for functional data analysis.
Each row of the resulting matrix corresponds to a subject, and each column to a voxel's PET intensity
values at a specified brain slice.
}
\details{
This function performs the following steps
\enumerate{
  \item Verifies that the specified z-slice exists in the database.
  \item Identifies the correct subject grouping column (\code{CN_number} or \code{AD_number}).
  \item Determines the matrix dimensions using \code{x} and \code{y} coordinates.
  \item Extracts PET intensities per subject at the given slice.
  \item Replaces any \code{NaN} values with \code{0} to ensure numerical stability.
}

This function typically follows \code{\link{databaseCreator}} and precedes
\code{\link{meanNormalization}} in the neuroSCC workflow.
}
\examples{
# NOTE: To keep example runtime short, only one synthetic PET file is used.
# For full analysis, expand the filename pattern accordingly.

# Step 1: Generate a database for a single subject
controlPattern <- "^syntheticControl1\\\\.nii\\\\.gz$"
databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)

# Step 2: Convert the database into a matrix format
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)

# Display dimensions of the matrix
dim(matrixControls)

}
\seealso{
\code{\link{databaseCreator}} for generating the input database. \cr
\code{\link{meanNormalization}} for scaling matrix data prior to SCC computation.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/processROIs.R
\name{processROIs}
\alias{processROIs}
\title{Process ROI Voxel Data from a NIfTI File}
\usage{
processROIs(
  roiFile,
  region,
  number,
  save = TRUE,
  outputDir = tempdir(),
  verbose = TRUE
)
}
\arguments{
\item{roiFile}{\code{character}. Path to the binary NIfTI file containing ROI data.}

\item{region}{\code{character}. Name of the ROI region (e.g., \code{"Region2"}).}

\item{number}{\code{character}. Identifier for the subject or group (e.g., \code{"18"}).}

\item{save}{\code{logical}. If \code{TRUE}, saves the result as an \code{.RDS} file. If \code{FALSE},
returns a data frame in the console. Default is \code{TRUE}.}

\item{outputDir}{\code{character}. Directory where the ROI table will be saved if \code{save = TRUE}.
Default is a temporary file: \code{tempdir()}.}

\item{verbose}{\code{logical}. If \code{TRUE}, displays progress messages. Default is \code{TRUE}.}
}
\value{
A data frame with voxel-level ROI information.
\itemize{
  \item \code{group} – Combined identifier built from \code{region} and \code{number}.
  \item \code{z}, \code{x}, \code{y} – Voxel coordinates.
  \item \code{pet} – Binary value indicating ROI membership (\code{1} = ROI, \code{0} = non-ROI).
}
If \code{save = TRUE}, the data frame is saved as an \code{.RDS} file and not returned to the console.
}
\description{
Processes Regions of Interest (ROIs) from a binary NIfTI file by extracting voxel-level
coordinates and labeling each voxel as part of the ROI or not. The function preserves the
spatial structure and is typically used to prepare ground truth ROIs for comparison with
SCC-detected regions via \code{\link{calculateMetrics}}.
}
\details{
The function uses \code{\link{neuroCleaner}} to load and flatten the NIfTI file into a structured
data frame. All voxels are retained, with the \code{pet} column indicating which ones are part
of the ROI (\code{1}) versus background (\code{0}). An ROI label is added in the \code{group} column.

This output is used as ground truth for evaluating detection performance in SCC analyses.
}
\examples{
# Load and process a sample ROI NIfTI file (console output)

}
\seealso{
\code{\link{calculateMetrics}} for evaluating SCC detection performance. \cr
\code{\link{neuroCleaner}} for reading and structuring voxel data.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotSCCpanel.R
\name{plotSCCpanel}
\alias{plotSCCpanel}
\title{Plot SCC bands and mean estimate for a single group}
\usage{
plotSCCpanel(scc, title = NULL, zlim = "auto", palette = "nih")
}
\arguments{
\item{scc}{A list-like SCC result object, typically returned by
\code{ImageSCC::scc.image()}, containing at least the components
\code{Z}, \code{ind.inside.cover}, \code{scc}, and \code{Yhat}.}

\item{title}{\code{character}, title shown above the panel. If \code{NULL},
the default title is \code{"SCC FOR GROUP 1"}.}

\item{zlim}{Either \code{"auto"} to compute color limits from the plotted values,
or a numeric vector of length 2 specifying the lower and upper limits of the
fill scale.}

\item{palette}{\code{character}, color palette used in the heatmaps.
Supported values are \code{"nih"}, \code{"viridis"}, and \code{"gray"}.}
}
\value{
A patchwork/ggplot object containing three aligned panels:
\itemize{
  \item lower SCC band,
  \item mean estimate,
  \item upper SCC band.
}
}
\description{
This function visualizes the lower band, mean estimate, and upper band
from a single-group Simultaneous Confidence Corridor (SCC) result.
It returns a three-panel plot showing the estimated mean function and
its confidence bands over the neuroimaging domain.
}
\details{
The three panels are displayed using a shared color scale so that the lower band,
mean estimate, and upper band can be compared directly.

The function assumes that the second slice of \code{scc$scc[, , 2]} corresponds
to the SCC bands for the default significance level used in the package workflow.
}
\examples{
data("sccOneGroup", package = "neuroSCC")
plotSCCpanel(sccOneGroup, title = "SCC FOR CONTROL GROUP")

}
\seealso{
\code{\link{sccOneGroup}} for the example single-group SCC object used in the examples. \cr
\code{\link{SCCcomp}} for a two-group SCC example object. \cr
\code{\link{plotSCCcomparisonPanel}} for two-group SCC visualization. \cr
\code{\link{plotValidationPanel}} for SCC versus SPM performance visualization.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/databaseCreator.R
\name{databaseCreator}
\alias{databaseCreator}
\title{Create a Database of Processed PET Image Data}
\usage{
databaseCreator(
  pattern,
  control = TRUE,
  useSequentialNumbering = FALSE,
  demo = NULL,
  quiet = FALSE
)
}
\arguments{
\item{pattern}{\code{character}. A regular expression defining the file pattern to match.
Subject identifiers are extracted from filenames based on this pattern.}

\item{control}{\code{logical}. If \code{TRUE}, files are treated as control group data;
if \code{FALSE}, as pathological group data. Default is \code{TRUE}.}

\item{useSequentialNumbering}{\code{logical}. If \code{TRUE}, assigns sequential subject numbers
instead of extracting them from filenames. Default is \code{FALSE}.}

\item{demo}{\code{data.frame}, optional. If provided, demographic information is included for each file.
Default is \code{NULL}.}

\item{quiet}{\code{logical}. If \code{TRUE}, suppresses progress messages. Default is \code{FALSE}.}
}
\value{
A \code{data.frame} combining processed voxel-level data from all matched files.
Each row represents a voxel (3D pixel). The column structure depends on input
\itemize{
  \item For the control group: \code{CN_number}, \code{z}, \code{x}, \code{y}, \code{pet}
  \item For the pathological group: \code{AD_number}, \code{z}, \code{x}, \code{y}, \code{pet}
  \item If demographics are included: additional columns \code{PPT}, \code{Group}, \code{Sex}, \code{Age}
}
}
\description{
Processes multiple PET image files matching a specified filename pattern.
Each file is processed using \code{\link{neuroCleaner}}, and the results are aggregated
into a unified data frame for functional data analysis. This function serves as a key step
in the \code{neuroSCC} workflow, bridging raw image data and Simultaneous Confidence Corridors (SCC) computation.
}
\details{
The function performs the following steps
\enumerate{
  \item Identifies image files matching the given pattern.
  \item Processes each file using \code{\link{neuroCleaner}}, optionally merging demographic data.
  \item Adds a subject identifier column (\code{CN_number} or \code{AD_number}).
  \item Aggregates all results into a single data frame.
}

If no files are successfully processed, an empty data frame is returned with a warning.

This function is typically followed by \code{\link{matrixCreator}}, which converts the output
into a matrix format for functional analysis.
}
\examples{
# NOTE: To keep runtime below CRAN limits, this example processes only 1 subject.
# You can expand the pattern to include all subjects for real use.

# Example: Create a database from a single synthetic PET image (control group)
controlPattern <- "^syntheticControl1\\\\.nii\\\\.gz$"
databaseControls <- databaseCreator(pattern = controlPattern, control = TRUE, quiet = TRUE)
head(databaseControls)

}
\seealso{
\code{\link{neuroCleaner}} for the underlying image processing function. \cr
\code{\link{matrixCreator}} for the next step in the workflow that converts
the database to a matrix format for SCC analysis.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/meanNormalization.R
\name{meanNormalization}
\alias{meanNormalization}
\title{Mean Normalization for Matrix Data}
\usage{
meanNormalization(
  matrixData,
  handleInvalidRows = c("warn", "error", "omit"),
  returnDetails = FALSE,
  quiet = FALSE
)
}
\arguments{
\item{matrixData}{A \code{matrix} where each row represents one subject’s PET data,
typically generated by \code{\link{matrixCreator}}.}

\item{handleInvalidRows}{\code{character}. Specifies how to handle rows with invalid means (either zero or \code{NA}).
Options include \code{"warn"} (default), \code{"error"}, or \code{"omit"}.}

\item{returnDetails}{\code{logical}. If \code{TRUE}, returns a list with the normalized matrix and
additional diagnostics. If \code{FALSE} (default), returns only the normalized matrix.}

\item{quiet}{\code{logical}. If \code{TRUE}, suppresses console messages. Default is \code{FALSE}.}
}
\value{
A normalized matrix, or a list if \code{returnDetails = TRUE}.
\itemize{
  \item \code{normalizedMatrix} – The normalized matrix.
  \item \code{problemRows} – Indices of rows that had zero or \code{NA} means.
}
}
\description{
Normalizes each row of a matrix by dividing its elements by the row mean, ignoring \code{NA} values.
This step is commonly used to adjust for global intensity differences across subjects before
applying statistical comparisons or functional data analysis.
}
\details{
The function performs the following steps
\enumerate{
  \item Computes the row means of the input matrix, ignoring \code{NA}s.
  \item Divides each row by its corresponding mean.
  \item Replaces \code{NaN} values (from division by 0) with \code{0} if applicable.
  \item Handles problematic rows according to the selected \code{handleInvalidRows} option:
        \code{"warn"} (default) issues a warning, \code{"error"} stops execution,
        and \code{"omit"} removes the affected rows from the result.
}

This step is often used prior to applying SCC methods to ensure comparability across subjects.
}
\examples{
# Generate a minimal database and create a matrix (1 control subject)
dataDir <- system.file("extdata", package = "neuroSCC")
controlPattern <- "^syntheticControl1\\\\.nii\\\\.gz$"
databaseControls <- databaseCreator(pattern = controlPattern,
                                    control = TRUE,
                                    quiet = TRUE)
matrixControls <- matrixCreator(databaseControls, paramZ = 35, quiet = TRUE)

# Normalize the matrix (with diagnostics)
normalizationResult <- meanNormalization(matrixControls,
                                         returnDetails = TRUE,
                                         quiet = FALSE)

}
\seealso{
\code{\link{matrixCreator}} for building the matrix input to normalize.
}
